@@ -47,18 +47,15 @@ typedef struct {
 	gint32		 max_col, max_row;
 	guint16		 col_xf    [SHEET_MAX_COLS];
 	GnmStyle	*col_style [SHEET_MAX_COLS];
-	GnmStyleList 	*conditions, *validations;
-	GSList           *blips, *textboxes;
-	unsigned	 cur_obj, num_objs, num_blips;
+	GnmStyleList 	*conditions, *hlinks, *validations;
+	GSList          *blips, *textboxes;
+	GHashTable	*comments;
+	unsigned	 cur_obj, num_objs;
 } ExcelWriteSheet;
 
-struct _ExcelWriteState {
-	BiffPut	      *bp;
-
-	IOContext     *io_context;
-	Workbook      const *gnum_wb;
-	WorkbookView  const *gnum_wb_view;
-	GPtrArray     *sheets;
+typedef struct {
+	Workbook      const *wb;
+	WorkbookView  const *wb_view;
 
 	struct {
 		TwoWayTable *two_way_table;
@@ -75,7 +72,15 @@ struct _ExcelWriteState {
 	struct {
 		TwoWayTable *two_way_table;
 	} formats;
+} XLExportBase;
 
+struct _ExcelWriteState {
+	XLExportBase	base;
+
+	IOContext     *io_context;
+	BiffPut	      *bp;
+
+	GPtrArray     *esheets;
 	GHashTable    *function_map;
 	GHashTable    *sheet_pairs;
 	GHashTable    *cell_markup;
@@ -114,7 +119,7 @@ struct _ExcelWriteState {
 #define FILL_NONE 0
 #define FILL_SOLID 1
 #define FILL_MAGIC FILL_NONE
-#define BORDER_MAGIC STYLE_BORDER_NONE
+#define BORDER_MAGIC GNM_STYLE_BORDER_NONE
 
 typedef enum {
 	STR_NO_LENGTH		= 0,
@@ -134,7 +139,7 @@ unsigned excel_write_BOF	(BiffPut *bp, MsBiffFileType type);
 void	 excel_write_SETUP	(BiffPut *bp, ExcelWriteSheet *esheet);
 void	 excel_write_SCL	(BiffPut *bp, double zoom, gboolean force);
 
-gint palette_get_index (ExcelWriteState const *ewb, guint c);
+int palette_get_index (XLExportBase const *ewb, guint c);
 int excel_write_get_externsheet_idx (ExcelWriteState *wb,
 				     Sheet *gnum_sheeta,
 				     Sheet *gnum_sheetb);
@@ -142,7 +147,18 @@ int excel_write_get_externsheet_idx (ExcelWriteState *wb,
 int excel_write_map_errcode (GnmValue const *v);
 
 /* Shared with xlsx export */
+typedef struct {
+	GnmValidation const *v;
+	GnmInputMsg *msg;
+	GSList	    *ranges;
+} XLValInputPair;
+GHashTable *excel_collect_validations (GnmStyleList *ptr,
+				       int max_col, int max_row);
+GHashTable *excel_collect_hlinks      (GnmStyleList *ptr,
+				       int max_col, int max_row);
+
 void excel_sheet_extent (Sheet const *sheet, GnmRange *extent, GnmStyle **col_styles,
 			 int maxcols, int maxrows, IOContext *io_context);
 
+
 #endif /* GNM_MS_EXCEL_WRITE_H */
