@@ -242,6 +242,12 @@ paste_object (GnmPasteTarget const *pt, SheetObject const *src, int left, int to
 		if (dst != NULL) {
 			SheetObjectAnchor tmp;
 			sheet_object_anchor_cpy (&tmp, sheet_object_get_anchor (src));
+			if (pt->paste_flags & PASTE_TRANSPOSE) {
+				GnmCellPos origin;
+				origin.col = 0;
+				origin.row = 0;
+				range_transpose (&tmp.cell_bound, &origin);
+			}
 			range_translate (&tmp.cell_bound, left, top);
 			sheet_object_set_anchor (dst, &tmp);
 			sheet_object_set_sheet (dst, pt->sheet);
@@ -630,7 +636,11 @@ clipboard_copy_obj (Sheet *sheet, GSList *objects)
 		if (NULL != (so = sheet_object_dup (ptr->data))) {
 			anchor = sheet_object_get_anchor (so);
 
-	/* FIXME : This is only used in gnm_sog_write_image What is it for ?? */
+#warning FIXME : This is only used in gnm_sog_write_image
+/* NOTE #1 : It seems necessary to handle pasting an object that has been removed from
+ * the sheet after being added to the clipboard.  it seems like we would need
+ * this sort of information for anything that implements SheetObjectImageableIface 
+ **/
 			sheet_object_anchor_to_pts (anchor, sheet, coords);
 			w = fabs (coords[2] - coords[0]) + 1.5;
 			h = fabs (coords[3] - coords[1]) + 1.5;
