@@ -32,7 +32,7 @@
 
 #include <workbook.h>
 #include <workbook-control.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <workbook-view.h>
 #include <gui-util.h>
 #include <parse-util.h>
@@ -53,7 +53,6 @@
 
 #include <glade/glade.h>
 #include <string.h>
-#include <gdk/gdkkeysyms.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtkspinbutton.h>
@@ -296,7 +295,7 @@ dialog_tool_cmp (GtkTableChild *tchild, GtkWidget *widget)
  **/
 gboolean
 dialog_tool_init (GenericToolState *state,
-		  WorkbookControlGUI *wbcg,
+		  WBCGtk *wbcg,
 		  Sheet *sheet,
 		  char const *help_file,
 		  char const *gui_name,
@@ -575,7 +574,7 @@ corr_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
  *
  **/
 int
-dialog_correlation_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_correlation_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         GenericToolState *state;
 
@@ -588,7 +587,7 @@ dialog_correlation_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, CORRELATION_KEY))
 		return 0;
 
-	state = g_new (GenericToolState, 1);
+	state = g_new0 (GenericToolState, 1);
 
 	if (dialog_tool_init (state, wbcg, sheet, 
 			      GNUMERIC_HELP_LINK_CORRELATION,
@@ -694,7 +693,7 @@ cov_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
  *
  **/
 int
-dialog_covariance_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_covariance_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         GenericToolState *state;
 
@@ -707,7 +706,7 @@ dialog_covariance_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, COVARIANCE_KEY))
 		return 0;
 
-	state = g_new (GenericToolState, 1);
+	state = g_new0 (GenericToolState, 1);
 
 	if (dialog_tool_init (state, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_COVARIANCE,
@@ -784,7 +783,7 @@ rank_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
  *
  **/
 int
-dialog_ranking_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_ranking_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         GenericToolState *state;
 
@@ -797,7 +796,7 @@ dialog_ranking_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, RANK_PERCENTILE_KEY))
 		return 0;
 
-	state = g_new (GenericToolState, 1);
+	state = g_new0 (GenericToolState, 1);
 
 	if (dialog_tool_init (state, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_RANKING,
@@ -875,7 +874,7 @@ fourier_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
  *
  **/
 int
-dialog_fourier_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_fourier_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         GenericToolState *state;
 
@@ -888,7 +887,7 @@ dialog_fourier_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, FOURIER_KEY))
 		return 0;
 
-	state = g_new (GenericToolState, 1);
+	state = g_new0 (GenericToolState, 1);
 
 	if (dialog_tool_init (state, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_FOURIER_ANALYSIS,
@@ -1086,7 +1085,7 @@ desc_stat_tool_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
  *
  **/
 int
-dialog_descriptive_stat_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_descriptive_stat_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         DescriptiveStatState *state;
 
@@ -1099,9 +1098,9 @@ dialog_descriptive_stat_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, DESCRIPTIVE_STATS_KEY))
 		return 0;
 
-	state = g_new (DescriptiveStatState, 1);
+	state = g_new0 (DescriptiveStatState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_DESCRIPTIVE_STATS,
 			      "descriptive-stats.glade", "DescStats",
 			      _("Could not create the Descriptive Statistics "
@@ -1450,7 +1449,7 @@ dialog_ttest_realized (G_GNUC_UNUSED GtkWidget *widget,
  *
  **/
 int
-dialog_ttest_tool (WorkbookControlGUI *wbcg, Sheet *sheet, ttest_type test)
+dialog_ttest_tool (WBCGtk *wbcg, Sheet *sheet, ttest_type test)
 {
         TTestState *state;
 	GtkDialog *dialog;
@@ -1468,10 +1467,10 @@ dialog_ttest_tool (WorkbookControlGUI *wbcg, Sheet *sheet, ttest_type test)
 		return 0;
 	}
 
-	state = g_new (TTestState, 1);
+	state = g_new0 (TTestState, 1);
 	state->invocation = test;
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_MEAN_TESTS,
 			      "mean-tests.glade", "MeanTests",
 			      _("Could not create the Mean Tests Tool dialog."),
@@ -1481,8 +1480,6 @@ dialog_ttest_tool (WorkbookControlGUI *wbcg, Sheet *sheet, ttest_type test)
 			      GNM_EE_SINGLE_RANGE))
 		return 0;
 
-	g_object_set_data (G_OBJECT (state->base.dialog), "state", state);
-
 	state->paired_button  = glade_xml_get_widget (state->base.gui, "paired-button");
 	state->unpaired_button  = glade_xml_get_widget (state->base.gui, "unpaired-button");
 	state->variablespaired_label = glade_xml_get_widget (state->base.gui, "variablespaired-label");
@@ -1645,7 +1642,7 @@ ftest_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
  *
  **/
 int
-dialog_ftest_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_ftest_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         FTestToolState *state;
 
@@ -1658,9 +1655,9 @@ dialog_ftest_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, FTEST_KEY))
 		return 0;
 
-	state = g_new (FTestToolState, 1);
+	state = g_new0 (FTestToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_F_TEST_TWO_SAMPLE,
 			      "variance-tests.glade", "VarianceTests",
 			      _("Could not create the FTest Tool dialog."),
@@ -1838,7 +1835,7 @@ dialog_sampling_realized (G_GNUC_UNUSED GtkWidget *widget,
  *
  **/
 int
-dialog_sampling_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_sampling_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         SamplingState *state;
 
@@ -1852,9 +1849,9 @@ dialog_sampling_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 		return 0;
 	}
 
-	state = g_new (SamplingState, 1);
+	state = g_new0 (SamplingState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_SAMPLING,
 			      "sampling.glade", "Sampling",
 			      _("Could not create the Sampling Tool dialog."),
@@ -2049,7 +2046,7 @@ regression_tool_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
  *
  **/
 int
-dialog_regression_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_regression_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         RegressionToolState *state;
 
@@ -2062,9 +2059,9 @@ dialog_regression_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, REGRESSION_KEY))
 		return 0;
 
-	state = g_new (RegressionToolState, 1);
+	state = g_new0 (RegressionToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_REGRESSION,
 			      "regression.glade", "Regression",
 			      _("Could not create the Regression Tool dialog."),
@@ -2177,7 +2174,7 @@ exp_smoothing_tool_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
  *
  **/
 int
-dialog_exp_smoothing_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_exp_smoothing_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         ExpSmoothToolState *state;
 
@@ -2189,9 +2186,9 @@ dialog_exp_smoothing_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, EXP_SMOOTHING_KEY))
 		return 0;
 
-	state = g_new (ExpSmoothToolState, 1);
+	state = g_new0 (ExpSmoothToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_EXP_SMOOTHING,
 			      "exp-smoothing.glade",
 			      "ExpSmoothing",
@@ -2309,7 +2306,7 @@ average_tool_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
  *
  **/
 int
-dialog_average_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_average_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         AverageToolState *state;
 
@@ -2322,9 +2319,9 @@ dialog_average_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, AVERAGE_KEY))
 		return 0;
 
-	state = g_new (AverageToolState, 1);
+	state = g_new0 (AverageToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_MOVING_AVERAGES,
 			      "moving-averages.glade",
 			      "MovAverages",
@@ -2521,7 +2518,7 @@ histogram_tool_set_calculated (G_GNUC_UNUSED GtkWidget *widget,
  *
  **/
 int
-dialog_histogram_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_histogram_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         HistogramToolState *state;
 
@@ -2534,9 +2531,9 @@ dialog_histogram_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, HISTOGRAM_KEY))
 		return 0;
 
-	state = g_new (HistogramToolState, 1);
+	state = g_new0 (HistogramToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_HISTOGRAM,
 			      "histogram.glade", "Histogram",
 			      _("Could not create the Histogram Tool dialog."),
@@ -2703,7 +2700,7 @@ anova_single_tool_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
  *
  **/
 int
-dialog_anova_single_factor_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_anova_single_factor_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         AnovaSingleToolState *state;
 
@@ -2716,9 +2713,9 @@ dialog_anova_single_factor_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, ANOVA_SINGLE_KEY))
 		return 0;
 
-	state = g_new (AnovaSingleToolState, 1);
+	state = g_new0 (AnovaSingleToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_ANOVA_SINGLE_FACTOR,
 			      "anova-one.glade", "ANOVA",
 			      _("Could not create the ANOVA (single factor) "
@@ -2929,7 +2926,7 @@ anova_two_factor_tool_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
  *
  **/
 int
-dialog_anova_two_factor_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_anova_two_factor_tool (WBCGtk *wbcg, Sheet *sheet)
 {
         AnovaTwoFactorToolState *state;
 
@@ -2940,9 +2937,9 @@ dialog_anova_two_factor_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (gnumeric_dialog_raise_if_exists (wbcg, ANOVA_TWO_FACTOR_KEY))
 		return 0;
 
-	state = g_new (AnovaTwoFactorToolState, 1);
+	state = g_new0 (AnovaTwoFactorToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_ANOVA_TWO_FACTOR,
 			      "anova-two.glade", "ANOVA",
 			      _("Could not create the ANOVA (two factor) "
