@@ -29,7 +29,7 @@
 #include <commands.h>
 #include <workbook-control.h>
 #include <workbook.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <sheet.h>
 #include <value.h>
 #include <sheet-filter.h>
@@ -43,7 +43,7 @@
 
 typedef struct {
 	GladeXML           *gui;
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	GtkWidget          *dialog;
 	GnmFilter	   *filter;
 	unsigned	    field;
@@ -219,15 +219,16 @@ init_operator (AutoFilterState *state, GnmFilterOp op, GnmValue const *v,
 	}
 	gtk_combo_box_set_active (GTK_COMBO_BOX (w), i);
 
-	if (v != NULL) {
-		w = glade_xml_get_widget (state->gui, val_widget);
+	w = glade_xml_get_widget (state->gui, val_widget);
+	gnumeric_editable_enters (GTK_WINDOW (state->dialog), w);
+	if (v != NULL)
 		gtk_entry_set_text (GTK_ENTRY (w), content ? content : str);
-	}
+
 	g_free (content);
 }
 
 void
-dialog_auto_filter (WorkbookControlGUI *wbcg,
+dialog_auto_filter (WBCGtk *wbcg,
 		    GnmFilter *filter, int field,
 		    gboolean is_expr, GnmFilterCondition *cond)
 {
@@ -262,6 +263,7 @@ dialog_auto_filter (WorkbookControlGUI *wbcg,
 			G_CALLBACK (cb_top10_type_changed), state);
 	}
 
+	state->dialog = glade_xml_get_widget (state->gui, "dialog");
 	if (cond != NULL) {
 		GnmFilterOp const op = cond->op[0];
 		if (is_expr && 0 == (op & GNM_FILTER_OP_TYPE_MASK)) {
@@ -298,8 +300,6 @@ dialog_auto_filter (WorkbookControlGUI *wbcg,
 		}
 	}
 
-	state->dialog = glade_xml_get_widget (state->gui, "dialog");
-
 	w = glade_xml_get_widget (state->gui, "ok_button");
 	g_signal_connect (G_OBJECT (w),
 		"clicked",
