@@ -39,7 +39,7 @@
 #include <sort.h>
 #include <sheet.h>
 #include <sheet-view.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <gnumeric-gconf.h>
 #include <widgets/gnumeric-cell-renderer-toggle.h>
 #include <widgets/gnumeric-expr-entry.h>
@@ -56,7 +56,7 @@
 
 
 typedef struct {
-	WorkbookControlGUI  *wbcg;
+	WBCGtk  *wbcg;
 	Workbook  *wb;
 	SheetView *sv;
 	Sheet     *sheet;
@@ -1133,7 +1133,7 @@ dialog_init (SortFlowState *state)
  * Main entry point for the Cell Sort dialog box
  */
 void
-dialog_cell_sort (WorkbookControlGUI *wbcg)
+dialog_cell_sort (WBCGtk *wbcg)
 {
 	SortFlowState *state;
 	GladeXML *gui;
