@@ -17,15 +17,16 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialogs.h"
+#include "help.h"
 
 #include <gui-util.h>
 #include <commands.h>
 #include <workbook-control.h>
 #include <workbook.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <sheet.h>
 #include <sheet-view.h>
 #include <workbook-cmd-format.h>
@@ -35,7 +36,7 @@
 
 typedef struct {
 	GladeXML           *gui;
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	Sheet              *sheet;
 	SheetView	   *sv;
 	GtkWidget          *dialog;
@@ -72,7 +73,7 @@ cb_pivottable_guru_cancel (G_GNUC_UNUSED GtkWidget *button,
 }
 
 void
-dialog_pivottable (WorkbookControlGUI *wbcg)
+dialog_pivottable (WBCGtk *wbcg)
 {
 	PivotTableGuru *state;
 	GladeXML *gui;
@@ -83,7 +84,7 @@ dialog_pivottable (WorkbookControlGUI *wbcg)
 	if (gnumeric_dialog_raise_if_exists (wbcg, DIALOG_KEY))
 		return;
 
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"pivottable.glade", NULL, NULL);
 	if (gui == NULL)
 		return;
@@ -108,7 +109,7 @@ dialog_pivottable (WorkbookControlGUI *wbcg)
 	/* a candidate for merging into attach guru */
 	gnumeric_init_help_button (
 		glade_xml_get_widget (state->gui, "help_button"),
-		"pivottable.html");
+		GNUMERIC_HELP_LINK_PIVOT_TABLE);
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify)cb_pivottable_guru_destroy);
 	wbcg_edit_attach_guru (state->wbcg, state->dialog);
