@@ -27,7 +27,7 @@
 #include "gui-gnumeric.h"
 #include "gui-util.h"
 #include "dialogs/help.h"
-#include "workbook-edit.h"
+#include "wbc-gtk.h"
 #include "commands.h"
 #include "sheet-object.h"
 #include <goffice/app/go-cmd-context.h>
@@ -38,7 +38,7 @@
 
 typedef struct {
 	GObject			*so;
-	WorkbookControlGUI	*wbcg;
+	WBCGtk	*wbcg;
 	GogStyle		*orig_style;
 } DialogSOStyled;
 
@@ -71,7 +71,7 @@ cb_dialog_so_styled_response (GtkWidget *dialog,
 }
 
 void
-dialog_so_styled (WorkbookControlGUI *wbcg,
+dialog_so_styled (WBCGtk *wbcg,
 		  GObject *so, GogStyle *orig, GogStyle *default_style,
 		  char const *title)
 {
