@@ -32,7 +32,7 @@
 #include <glade/glade.h>
 #include <widgets/gnumeric-expr-entry.h>
 #include <tools/tabulate.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include "ranges.h"
 #include "value.h"
 #include "sheet.h"
@@ -65,7 +65,7 @@ enum {
 };
 
 typedef struct {
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	Sheet *sheet;
 
 	GladeXML *gui;
@@ -92,7 +92,7 @@ free_state (DialogState *dd)
 }
 
 static void
-non_model_dialog (WorkbookControlGUI *wbcg,
+non_model_dialog (WBCGtk *wbcg,
 		  GtkDialog *dialog,
 		  const char *key)
 {
@@ -151,7 +151,7 @@ get_table_float_entry (GtkTable *t, int y, int x, GnmCell *cell, gnm_float *numb
 		if (child->left_attach == x && child->top_attach == y &&
 		    GTK_IS_ENTRY (child->widget)) {
 			*wp = GTK_ENTRY (child->widget);
-			format = gnm_style_get_format (cell_get_style (cell));
+			format = gnm_style_get_format (gnm_cell_get_style (cell));
 			return (with_default ?
 				entry_to_float_with_format_default (GTK_ENTRY (child->widget), number,
 							   TRUE, format, default_float) :
@@ -163,7 +163,7 @@ get_table_float_entry (GtkTable *t, int y, int x, GnmCell *cell, gnm_float *numb
 }
 
 static void
-dialog_destroy (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
+cb_dialog_destroy (DialogState *dd)
 {
 	wbcg_edit_detach_guru (dd->wbcg);
 	free_state (dd);
@@ -206,7 +206,7 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 			gnm_expr_entry_grab_focus (GNM_EXPR_ENTRY (w), TRUE);
 			goto error;
 		}
-		if (cell_has_expr (cells[dims])) {
+		if (gnm_cell_has_expr (cells[dims])) {
 			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
 					 GTK_MESSAGE_ERROR,
 					 _("The dependency cells should not contain an expression"));
@@ -278,7 +278,7 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 			goto error;
 		}
 
-		if (!cell_has_expr (resultcell)) {
+		if (!gnm_cell_has_expr (resultcell)) {
 			go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
 					 GTK_MESSAGE_ERROR,
 					 _("The target cell should contain an expression"));
@@ -315,7 +315,7 @@ tabulate_ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 }
 
 void
-dialog_tabulate (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_tabulate (WBCGtk *wbcg, Sheet *sheet)
 {
 	GladeXML *gui;
 	GtkDialog *dialog;
@@ -384,10 +384,11 @@ dialog_tabulate (WorkbookControlGUI *wbcg, Sheet *sheet)
 	gnumeric_init_help_button (
 		glade_xml_get_widget (gui, "help_button"),
 		GNUMERIC_HELP_LINK_TABULATE);
+	g_object_set_data_full (G_OBJECT (dialog),
+		"state", dd, (GDestroyNotify) cb_dialog_destroy);
 
-	g_signal_connect (G_OBJECT (dialog),
-		"destroy",
-		G_CALLBACK (dialog_destroy), dd);
+	gnm_dialog_setup_destroy_handlers (dialog, wbcg,
+					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
 
 	gtk_widget_show_all (dialog->vbox);
 	wbcg_edit_attach_guru (wbcg, GTK_WIDGET (dialog));
