@@ -19,21 +19,22 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
 #include "application.h"
 #include <glade/glade.h>
 #include <gui-util.h>
-#include <workbook-control-gui.h>
+#include <wbc-gtk.h>
+
 #include <gtk/gtkradiobutton.h>
 #include <gtk/gtkbox.h>
+#include <glib/gi18n-lib.h>
 
 #define VIEW_DIALOG_KEY "view-dialog"
 
 typedef struct {
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	GtkWidget          *dialog;
 	GladeXML           *gui;
 	GtkRadioButton     *location_elsewhere;
@@ -51,7 +52,7 @@ static void
 cb_view_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 		    ViewState *state)
 {
-	WorkbookControlGUI *wbcg = state->wbcg;
+	WBCGtk *wbcg = state->wbcg;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	WorkbookControl *new_wbc;
 	gboolean shared;
@@ -97,12 +98,12 @@ cb_view_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 	new_wbc = wb_control_wrapper_new
 		(wbc,
 		 shared ? wb_control_view (wbc) : NULL,
-		 wb_control_workbook (wbc),
+		 wb_control_get_workbook (wbc),
 		 screen);
 
-	if (IS_WORKBOOK_CONTROL_GUI (new_wbc)) {
+	if (IS_WBC_GTK (new_wbc)) {
 		/* What else would it be?  */
-		WorkbookControlGUI *new_wbcg = WORKBOOK_CONTROL_GUI (new_wbc);
+		WBCGtk *new_wbcg = WBC_GTK (new_wbc);
 		wbcg_copy_toolbar_visibility (new_wbcg, wbcg);
 		_gnm_app_flag_windows_changed ();
 	}
@@ -121,7 +122,7 @@ cb_view_destroy (ViewState *state)
 }
 
 void
-dialog_new_view (WorkbookControlGUI *wbcg)
+dialog_new_view (WBCGtk *wbcg)
 {
 	ViewState *state;
 	GladeXML *gui;
