@@ -101,7 +101,7 @@ check_name_match (char const *name, char const *description, char const *tag)
 	char *desc_name, *up_name;
 
 	if (NULL == (tmp = strstr (description, tag))) {
-		fprintf (stderr, "'%s' : missing '%s' section.  text = '%s'\n", name, tag, description);
+		g_printerr ("'%s' : missing '%s' section.  text = '%s'\n", name, tag, description);
 		return NULL;
 	}
 
@@ -111,7 +111,7 @@ check_name_match (char const *name, char const *description, char const *tag)
 	desc_name = g_strndup (description, tmp-description);
 	up_name = g_ascii_strup (name, -1);
 	if (strcmp (desc_name, up_name)) {
-		fprintf (stderr, "'%s' : does not match '%s' in @FUNCTION\n", desc_name, up_name);
+		g_printerr ("'%s' : does not match '%s' in @FUNCTION\n", desc_name, up_name);
 		g_free (up_name);
 		g_free (desc_name);
 		return NULL;
@@ -150,14 +150,14 @@ cb_generate_po (gpointer key, Symbol *sym, gpointer array)
 		return;
 
 	if (NULL == (tmp = strstr (ptr, "@DESCRIPTION="))) {
-		fprintf (stderr, "'%s' : missing @DESCRIPTION section\n", fd->name);
+		g_printerr ("'%s' : missing @DESCRIPTION section\n", fd->name);
 		return;
 	}
 	if (NULL == (tmp = strstr (ptr, "@EXAMPLES="))) {
 		return;
 	}
 	if (NULL == (tmp = strstr (ptr, "@SEEALSO="))) {
-		fprintf (stderr, "'%s' : missing @SEEALSO section\n", fd->name);
+		g_printerr ("'%s' : missing @SEEALSO section\n", fd->name);
 		return;
 	}
 }
@@ -639,7 +639,7 @@ gnm_func_unref (GnmFunc *func)
 }
 
 GnmFunc *
-gnm_func_lookup (char const *name, Workbook const *scope)
+gnm_func_lookup (char const *name, Workbook *scope)
 {
 	Symbol *sym = symbol_lookup (global_symbol_table, name);
 	if (sym != NULL)
@@ -798,17 +798,6 @@ gnm_func_add_placeholder (Workbook *scope,
 	return func;
 }
 
-/* See type GnmParseFunctionHandler */
-GnmExpr const *
-gnm_func_placeholder_factory (char const *name,
-			      GnmExprList *args,
-			      G_GNUC_UNUSED GnmExprConventions const *convs)
-{
-	GnmFunc *f = gnm_func_add_placeholder (NULL, name, "", TRUE);
-	return gnm_expr_new_funcall (f, args);
-}
-
-
 gpointer
 gnm_func_get_user_data (GnmFunc const *func)
 {
@@ -1483,17 +1472,24 @@ function_iterate_argument_values (GnmEvalPos const	*ep,
 			continue;
 		}
 
-		/* We need a cleaner model of what to do here.  For now it
-		 * seems as if var-arg functions treat explict ranges as special cases
-		 * 	SUM(Range) or
-		 * 	SUM(INDIRECT(foo))
-		 * will pass the range not do implicit intersection in non-array mode
+		/* We need a cleaner model of what to do here.
+		 * In non-array mode
+		 * 	SUM(Range)
+		 * will obviously return Range
+		 *
+		 * 	SUM(INDIRECT(Range))
+		 * 	SUM(INDIRECT(Range):....)
+		 * will do implicit intersection on Range (in non-array mode),
+		 * but allow non-scalar results from indirect (no intersection)
+		 *
 		 * 	SUM(Range=3)
 		 * will do implicit intersection in non-array mode */
 		if (GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_CONSTANT)
 			val = value_dup (expr->constant.value);
 		else if (ep->array != NULL ||
-			 GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_FUNCALL)
+			 GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_FUNCALL ||
+			 GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_RANGE_CTOR ||
+			 GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_INTERSECT)
 			val = gnm_expr_eval (expr, ep,
 				GNM_EXPR_EVAL_PERMIT_EMPTY | GNM_EXPR_EVAL_PERMIT_NON_SCALAR);
 		else
