@@ -26,9 +26,7 @@
 #include "sheet-view.h"
 #include "application.h"
 #include "workbook-view.h"
-#include "workbook-edit.h"
-#include "workbook-control-gui.h"
-#include "workbook-control-gui-priv.h"
+#include "wbc-gtk-impl.h"
 #include "workbook.h"
 #include "workbook-cmd-format.h"
 #include "commands.h"
@@ -81,7 +79,7 @@ static GtkTargetEntry const drag_types_out[] = {
 };
 
 static gboolean
-gnm_pane_guru_key (WorkbookControlGUI const *wbcg, GdkEventKey *event)
+gnm_pane_guru_key (WBCGtk const *wbcg, GdkEventKey *event)
 {
 	GtkWidget *entry, *guru = wbcg_edit_get_guru (wbcg);
 
@@ -178,7 +176,7 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 	SheetControl *sc = (SheetControl *) scg;
 	Sheet *sheet = sc->sheet;
 	SheetView *sv = sc->view;
-	WorkbookControlGUI *wbcg = scg->wbcg;
+	WBCGtk *wbcg = scg->wbcg;
 	gboolean delayed_movement = FALSE;
 	gboolean jump_to_bounds = event->state & GDK_CONTROL_MASK;
 	gboolean is_enter = FALSE;
@@ -404,7 +402,7 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 
 		/* Be careful to restore the editing sheet if we are editing */
 		if (wbcg_is_editing (wbcg))
-			sheet = wbcg->wb_control.editing_sheet;
+			sheet = wbcg->editing_sheet;
 
 		if (wbcg_edit_finish (wbcg, WBC_EDIT_ACCEPT, NULL)) {
 			if ((event->state & GDK_MOD1_MASK) &&
@@ -764,7 +762,7 @@ static void
 cb_gnm_pane_commit (GtkIMContext *context, char const *str, GnmPane *pane)
 {
 	gint tmp_pos, length;
-	WorkbookControlGUI *wbcg = pane->simple.scg->wbcg;
+	WBCGtk *wbcg = pane->simple.scg->wbcg;
 	GtkEditable *editable = gnm_pane_get_editable (pane);
 
 	if (!wbcg_is_editing (wbcg) && !wbcg_edit_start (wbcg, TRUE, TRUE))
@@ -796,7 +794,7 @@ cb_gnm_pane_preedit_changed (GtkIMContext *context, GnmPane *pane)
 	gchar *preedit_string;
 	int tmp_pos;
 	int cursor_pos;
-	WorkbookControlGUI *wbcg = pane->simple.scg->wbcg;
+	WBCGtk *wbcg = pane->simple.scg->wbcg;
 	GtkEditable *editable = gnm_pane_get_editable (pane);
 
 	tmp_pos = gtk_editable_get_position (editable);
@@ -857,17 +855,23 @@ cb_gnm_pane_delete_surrounding (GtkIMContext *context,
 	return TRUE;
 }
 
+/* create views for the sheet objects now that we exist */
 static void
 cb_pane_init_objs (GnmPane *pane)
 {
-	/* create views for the sheet objects now that we exist */
 	Sheet *sheet = scg_sheet (pane->simple.scg);
-	GSList *ptr;
+	GSList *ptr, *list;
 
-	if (sheet != NULL)
-		for (ptr = sheet->sheet_objects; ptr != NULL ; ptr = ptr->next)
+	if (sheet != NULL) {
+		/* List is stored in reverse stacking order.  Top of stack is
+		 * first.  On creation new foocanvas item get added to
+		 * the front, so we need to create the views in reverse order */
+		list = g_slist_reverse (g_slist_copy (sheet->sheet_objects));
+		for (ptr = list; ptr != NULL ; ptr = ptr->next)
 			sheet_object_new_view (ptr->data,
 				(SheetObjectViewContainer *)pane);
+		g_slist_free (list);
+	}
 }
 
 static void
@@ -1072,7 +1076,7 @@ cb_pane_drag_leave (GtkWidget *widget, GdkDragContext *context,
 {
 	GtkWidget *source_widget = gtk_drag_get_source_widget (context);
 	GnmPane *source_pane;
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
   
 	if (!source_widget || !IS_GNM_PANE (source_widget)) return;
 
