@@ -50,14 +50,18 @@ gnm_go_data_dup (GOData const *src)
 	GnmDependent const *src_dep = gnm_go_data_get_dep (src);
 	GnmDependent *dst_dep = gnm_go_data_get_dep (dst);
 
-	dst_dep->expression = src_dep->expression;
-	dst_dep->sheet      = src_dep->sheet;
-	if (dst_dep->expression == NULL) {
+	dst_dep->texpr = src_dep->texpr;
+	if (dst_dep->texpr)
+		gnm_expr_top_ref (dst_dep->texpr);
+
+	if (src_dep->sheet)
+		dependent_set_sheet (dst_dep, src_dep->sheet);
+
+	if (dst_dep->texpr == NULL) {
 		char const *str = g_object_get_data (G_OBJECT (src), "from-str");
 		g_object_set_data_full (G_OBJECT (dst),
 			"from-str", g_strdup (str), g_free);
-	} else
-		gnm_expr_ref (dst_dep->expression);
+	}
 
 	return GO_DATA (dst);
 }
@@ -67,7 +71,7 @@ gnm_go_data_eq (GOData const *data_a, GOData const *data_b)
 {
 	GnmDependent const *a = gnm_go_data_get_dep (data_a);
 	GnmDependent const *b = gnm_go_data_get_dep (data_b);
-	if (a->expression == NULL && b->expression == NULL) {
+	if (a->texpr == NULL && b->texpr == NULL) {
 		char const *str_a = g_object_get_data (G_OBJECT (data_a), "from-str");
 		char const *str_b = g_object_get_data (G_OBJECT (data_b), "from-str");
 
@@ -76,7 +80,7 @@ gnm_go_data_eq (GOData const *data_a, GOData const *data_b)
 		return FALSE;
 	}
 
-	return gnm_expr_equal (a->expression, b->expression);
+	return gnm_expr_top_equal (a->texpr, b->texpr);
 }
 
 static GOFormat *
@@ -84,8 +88,14 @@ gnm_go_data_preferred_fmt (GOData const *dat)
 {
 	GnmEvalPos ep;
 	GnmDependent const *dep = gnm_go_data_get_dep (dat);
-	return auto_style_format_suggest (dep->expression,
-		eval_pos_init_dep (&ep, dep));
+
+	g_return_val_if_fail (dep != NULL, NULL);
+	g_return_val_if_fail (dep->sheet != NULL, NULL);
+
+	eval_pos_init_dep (&ep, dep);
+	return dep->texpr
+		? auto_style_format_suggest (dep->texpr, &ep)
+		: NULL;
 }
 
 static char *
@@ -95,19 +105,19 @@ gnm_go_data_as_str (GOData const *dat)
 	GnmDependent const *dep = gnm_go_data_get_dep (dat);
 	if (dep->sheet == NULL)
 		return g_strdup ("No sheet for GnmGOData");
-	return gnm_expr_as_string (dep->expression,
+	return gnm_expr_top_as_string (dep->texpr,
 		parse_pos_init_dep (&pp, dep),
-		gnm_expr_conventions_default);
+		gnm_conventions_default);
 }
 
 static  gboolean
 gnm_go_data_from_str (GOData *dat, char const *str)
 {
-	GnmExpr const *expr;
+	GnmExprTop const *texpr;
 	GnmParsePos   pp;
 	GnmDependent *dep = gnm_go_data_get_dep (dat);
 
-	/* Its too early in the life cycle to know where we
+	/* It is too early in the life cycle to know where we
 	 * are.  Wait until later when we parse the sheet */
 	if (dep->sheet == NULL) {
 		g_object_set_data_full (G_OBJECT (dat),
@@ -115,10 +125,10 @@ gnm_go_data_from_str (GOData *dat, char const *str)
 		return TRUE;
 	}
 
-	expr = gnm_expr_parse_str_simple (str, parse_pos_init_dep (&pp, dep));
-	if (expr != NULL) {
-		dependent_set_expr (dep, expr);
-		gnm_expr_unref (expr);
+	texpr = gnm_expr_parse_str_simple (str, parse_pos_init_dep (&pp, dep));
+	if (texpr != NULL) {
+		dependent_set_expr (dep, texpr);
+		gnm_expr_top_unref (texpr);
 		return TRUE;
 	}
 	return FALSE;
@@ -132,10 +142,14 @@ gnm_go_data_set_sheet (GOData *dat, Sheet *sheet)
 	if (dep == NULL)
 		return;
 
+	if (dependent_is_linked (dep)) {
+		dependent_unlink (dep);
+		dep->sheet = NULL;
+	}
 	if (sheet != NULL) {
 		/* no expression ?
 		 * Do we need to parse one now that we have more context ? */
-		if (dep->expression == NULL) {
+		if (dep->texpr == NULL) {
 			char const *str = g_object_get_data (G_OBJECT (dat), "from-str");
 			if (str != NULL) { /* bingo */
 				dep->sheet = sheet; /* cheat a bit */
@@ -149,9 +163,6 @@ gnm_go_data_set_sheet (GOData *dat, Sheet *sheet)
 
 		dep->sheet = NULL;
 		dependent_set_sheet (dep, sheet);
-	} else if (dependent_is_linked (dep)) {
-		dependent_unlink (dep);
-		dep->sheet = NULL;
 	}
 }
 
@@ -163,12 +174,21 @@ gnm_go_data_get_sheet (GOData const *dat)
 	return dep->sheet;
 }
 
-GnmExpr const *
+GnmExprTop const *
 gnm_go_data_get_expr (GOData const *dat)
 {
 	GnmDependent *dep = gnm_go_data_get_dep (dat);
 	g_return_val_if_fail (dep != NULL, NULL);
-	return dep->expression;
+	return dep->texpr;
+}
+
+void
+gnm_go_data_foreach_dep (GOData *dat, SheetObject *so,
+			 SheetObjectForeachDepFunc func, gpointer user)
+{
+	GnmDependent *dep = gnm_go_data_get_dep (dat);
+	if (dep)
+		func (dep, so, user);
 }
 
 /**************************************************************************/
@@ -195,9 +215,9 @@ scalar_get_val (GnmGODataScalar *scalar)
 		scalar->val_str = NULL;
 	}
 	if (scalar->val == NULL) {
-		if (scalar->dep.expression != NULL) {
+		if (scalar->dep.texpr != NULL) {
 			GnmEvalPos pos;
-			scalar->val = gnm_expr_eval (scalar->dep.expression,
+			scalar->val = gnm_expr_top_eval (scalar->dep.texpr,
 				eval_pos_init_dep (&pos, &scalar->dep),
 				GNM_EXPR_EVAL_PERMIT_EMPTY);
 		} else
@@ -233,7 +253,7 @@ gnm_go_data_scalar_finalize (GObject *obj)
 	g_free (scalar->val_str);
 	scalar->val_str = NULL;
 
-	(*scalar_parent_klass->finalize) (obj);
+	scalar_parent_klass->finalize (obj);
 }
 
 static double
@@ -288,10 +308,10 @@ GSF_CLASS (GnmGODataScalar, gnm_go_data_scalar,
 	   GO_DATA_SCALAR_TYPE)
 
 GOData *
-gnm_go_data_scalar_new_expr (Sheet *sheet, GnmExpr const *expr)
+gnm_go_data_scalar_new_expr (Sheet *sheet, GnmExprTop const *texpr)
 {
 	GnmGODataScalar *res = g_object_new (gnm_go_data_scalar_get_type (), NULL);
-	res->dep.expression = expr;
+	res->dep.texpr = texpr;
 	res->dep.sheet = sheet;
 	return GO_DATA (res);
 }
@@ -332,12 +352,11 @@ gnm_go_data_vector_finalize (GObject *obj)
 		value_release (vec->val);
 		vec->val = NULL;
 	}
-	if (vec->base.values != NULL) {
-		g_free (vec->base.values);
-		vec->base.values = NULL;
-	}
 
-	(*vector_parent_klass->finalize) (obj);
+	g_free (vec->base.values);
+	vec->base.values = NULL;
+
+	vector_parent_klass->finalize (obj);
 }
 
 static void
@@ -351,8 +370,8 @@ gnm_go_data_vector_load_len (GODataVector *dat)
 	int old_len = dat->len;
 
 	eval_pos_init_dep (&ep, &vec->dep);
-	if (vec->val == NULL && vec->dep.expression != NULL)
-		vec->val = gnm_expr_eval (vec->dep.expression, &ep,
+	if (vec->val == NULL && vec->dep.texpr != NULL)
+		vec->val = gnm_expr_top_eval (vec->dep.texpr, &ep,
 			GNM_EXPR_EVAL_PERMIT_NON_SCALAR | GNM_EXPR_EVAL_PERMIT_EMPTY);
 
 #if 0
@@ -366,7 +385,7 @@ gnm_go_data_vector_load_len (GODataVector *dat)
 	if (vec->val != NULL) {
 		switch (vec->val->type) {
 		case VALUE_CELLRANGE:
-			rangeref_normalize (&vec->val->v_range.cell, &ep,
+			gnm_rangeref_normalize (&vec->val->v_range.cell, &ep,
 				&start_sheet, &end_sheet, &r);
 
 			if (r.end.col > start_sheet->cols.max_used)
@@ -411,15 +430,14 @@ struct assign_closure {
 };
 
 static GnmValue *
-cb_assign_val (Sheet *sheet, int col, int row,
-	       GnmCell *cell, struct assign_closure *dat)
+cb_assign_val (GnmCellIter const *iter, struct assign_closure *dat)
 {
 	GnmValue *v;
 	double res;
 
-	if (cell != NULL) {
-		cell_eval (cell);
-		v = cell->value;
+	if (iter->cell != NULL) {
+		gnm_cell_eval (iter->cell);
+		v = iter->cell->value;
 	} else
 		v = NULL;
 
@@ -429,9 +447,9 @@ cb_assign_val (Sheet *sheet, int col, int row,
 	}
 
 	dat->last = dat->i;
-	if (v->type == VALUE_STRING) {
+	if (VALUE_IS_STRING (v)) {
 		v = format_match_number (v->v_str.val->str, NULL,
-				workbook_date_conv (sheet->workbook));
+			workbook_date_conv (iter->pp.wb));
 		if (v == NULL) {
 			dat->vals[dat->i++] = gnm_pinf;
 			return NULL;
@@ -474,7 +492,7 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 	vals = dat->values;
 	switch (vec->val->type) {
 	case VALUE_CELLRANGE:
-		rangeref_normalize (&vec->val->v_range.cell,
+		gnm_rangeref_normalize (&vec->val->v_range.cell,
 			eval_pos_init_dep (&ep, &vec->dep),
 			&start_sheet, &end_sheet, &r);
 
@@ -518,7 +536,7 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 			if (VALUE_IS_EMPTY_OR_ERROR (v)) {
 				vals[len] = go_nan;
 				continue;
-			} else if (v->type == VALUE_STRING) {
+			} else if (VALUE_IS_STRING (v)) {
 				GnmValue *tmp = format_match_number (v->v_str.val->str, NULL,
 						workbook_date_conv (vec->dep.sheet->workbook));
 				if (tmp == NULL) {
@@ -567,7 +585,7 @@ gnm_go_data_vector_get_value (GODataVector *dat, unsigned i)
 	GnmGODataVector *vec = (GnmGODataVector *)dat;
 	GnmValue *v;
 	GnmEvalPos ep;
-	gboolean valid;
+	gboolean valid = FALSE;
 
 	if (vec->val == NULL)
 		gnm_go_data_vector_load_len (dat);
@@ -576,8 +594,10 @@ gnm_go_data_vector_get_value (GODataVector *dat, unsigned i)
 	v = value_dup (vec->as_col
 		? value_area_get_x_y (vec->val, 0, i, &ep)
 		: value_area_get_x_y (vec->val, i, 0, &ep));
-	v = value_coerce_to_number (v, &valid, &ep);
+	if (NULL == v)
+		return go_nan;
 
+	v = value_coerce_to_number (v, &valid, &ep);
 	if (valid) {
 		gnm_float res = value_get_as_float (v);
 		value_release (v);
@@ -608,8 +628,8 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 		GnmCell  *cell;
 		GnmRange  r;
 
-		rangeref_normalize (&v->v_range.cell, &ep,
-				    &start_sheet, &end_sheet, &r);
+		gnm_rangeref_normalize (&v->v_range.cell, &ep,
+			&start_sheet, &end_sheet, &r);
 		if (vec->as_col)
 			r.start.row += i;
 		else
@@ -617,9 +637,9 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 		cell = sheet_cell_get (start_sheet, r.start.col, r.start.row);
 		if (cell == NULL)
 			return NULL;
-		cell_eval (cell);
+		gnm_cell_eval (cell);
 		v = cell->value;
-		format = cell_get_format (cell);
+		format = gnm_cell_get_format (cell);
 		date_conv = workbook_date_conv (start_sheet->workbook);
 	} else if (v->type == VALUE_ARRAY)
 		v = vec->as_col
@@ -675,10 +695,10 @@ GSF_CLASS (GnmGODataVector, gnm_go_data_vector,
 	   GO_DATA_VECTOR_TYPE)
 
 GOData *
-gnm_go_data_vector_new_expr (Sheet *sheet, GnmExpr const *expr)
+gnm_go_data_vector_new_expr (Sheet *sheet, GnmExprTop const *texpr)
 {
 	GnmGODataVector *res = g_object_new (gnm_go_data_vector_get_type (), NULL);
-	res->dep.expression = expr;
+	res->dep.texpr = texpr;
 	res->dep.sheet = sheet;
 	return GO_DATA (res);
 }
@@ -718,12 +738,11 @@ gnm_go_data_matrix_finalize (GObject *obj)
 		value_release (mat->val);
 		mat->val = NULL;
 	}
-	if (mat->base.values != NULL) {
-		g_free (mat->base.values);
-		mat->base.values = NULL;
-	}
 
-	(*matrix_parent_klass->finalize) (obj);
+	g_free (mat->base.values);
+	mat->base.values = NULL;
+
+	matrix_parent_klass->finalize (obj);
 }
 
 static void
@@ -738,7 +757,7 @@ gnm_go_data_matrix_load_size (GODataMatrix *dat)
 
 	eval_pos_init_dep (&ep, &mat->dep);
 	if (mat->val == NULL)
-		mat->val = gnm_expr_eval (mat->dep.expression, &ep,
+		mat->val = gnm_expr_top_eval (mat->dep.texpr, &ep,
 			GNM_EXPR_EVAL_PERMIT_NON_SCALAR | GNM_EXPR_EVAL_PERMIT_EMPTY);
 
 #if 0
@@ -752,7 +771,7 @@ gnm_go_data_matrix_load_size (GODataMatrix *dat)
 	if (mat->val != NULL) {
 		switch (mat->val->type) {
 		case VALUE_CELLRANGE:
-			rangeref_normalize (&mat->val->v_range.cell, &ep,
+			gnm_rangeref_normalize (&mat->val->v_range.cell, &ep,
 				&start_sheet, &end_sheet, &r);
 			if (r.end.col > start_sheet->cols.max_used)
 				r.end.col = start_sheet->cols.max_used;
@@ -806,23 +825,22 @@ struct assign_matrix_closure {
 };
 
 static GnmValue *
-cb_assign_matrix_val (Sheet *sheet, int col, int row,
-	       GnmCell *cell, struct assign_matrix_closure *dat)
+cb_assign_matrix_val (GnmCellIter const *iter,
+		      struct assign_matrix_closure *dat)
 {
 	GnmValue *v;
 	double res;
 
-	if (dat->first_row == -1)
-		dat->first_row = row;
-	dat->row = row - dat->first_row;
-
 	if (dat->first_col == -1)
-		dat->first_col = col;
-	dat->col = col - dat->first_col;
-	
-	if (cell != NULL) {
-		cell_eval (cell);
-		v = cell->value;
+		dat->first_col = iter->pp.eval.col;
+	dat->col = iter->pp.eval.col - dat->first_col;
+	if (dat->first_row == -1)
+		dat->first_row = iter->pp.eval.row;
+	dat->row = iter->pp.eval.row - dat->first_row;
+
+	if (iter->cell != NULL) {
+		gnm_cell_eval (iter->cell);
+		v = iter->cell->value;
 	} else
 		v = NULL;
 	
@@ -837,9 +855,9 @@ cb_assign_matrix_val (Sheet *sheet, int col, int row,
 	if (dat->last_col < dat->col)
 		dat->last_col = dat->col;
 
-	if (v->type == VALUE_STRING) {
+	if (VALUE_IS_STRING (v)) {
 		v = format_match_number (v->v_str.val->str, NULL,
-				workbook_date_conv (sheet->workbook));
+			workbook_date_conv (iter->pp.wb));
 		if (v == NULL) {
 			dat->vals[dat->row * dat->columns + dat->col] = go_nan;
 			/* may be go_pinf should be more appropriate? */
@@ -884,7 +902,7 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 	vals = dat->values;
 	switch (mat->val->type) {
 	case VALUE_CELLRANGE:
-		rangeref_normalize (&mat->val->v_range.cell,
+		gnm_rangeref_normalize (&mat->val->v_range.cell,
 			eval_pos_init_dep (&ep, &mat->dep),
 			&start_sheet, &end_sheet, &r);
 
@@ -902,7 +920,7 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 				r.start.col + dat->size.columns - 1,
 				r.start.row + dat->size.rows - 1,
 				(CellIterFunc)cb_assign_matrix_val, &closure);
-#warning Should we clip the matrix?
+#warning "Should we clip the matrix?"
 			minimum = closure.minimum;
 			maximum = closure.maximum;
 			if (minimum > maximum)
@@ -921,7 +939,7 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 				if (VALUE_IS_EMPTY_OR_ERROR (v)) {
 					vals[row * size.columns + col] = go_nan;
 					continue;
-				} else if (v->type == VALUE_STRING) {
+				} else if (VALUE_IS_STRING (v)) {
 					GnmValue *tmp = format_match_number (v->v_str.val->str, NULL,
 							workbook_date_conv (mat->dep.sheet->workbook));
 					if (tmp == NULL) {
@@ -981,8 +999,10 @@ gnm_go_data_matrix_get_value (GODataMatrix *dat, unsigned i, unsigned j)
 
 	eval_pos_init_dep (&ep, &mat->dep);
 	v = value_dup (value_area_get_x_y (mat->val, i, j, &ep));
-	v = value_coerce_to_number (v, &valid, &ep);
+	if (NULL == v)
+		return go_nan;
 
+	v = value_coerce_to_number (v, &valid, &ep);
 	if (valid) {
 		gnm_float res = value_get_as_float (v);
 		value_release (v);
@@ -1013,16 +1033,16 @@ gnm_go_data_matrix_get_str (GODataMatrix *dat, unsigned i, unsigned j)
 		GnmCell  *cell;
 		GnmRange  r;
 
-		rangeref_normalize (&v->v_range.cell, &ep,
-				    &start_sheet, &end_sheet, &r);
+		gnm_rangeref_normalize (&v->v_range.cell, &ep,
+			&start_sheet, &end_sheet, &r);
 		r.start.row += i;
 		r.start.col += j;
 		cell = sheet_cell_get (start_sheet, r.start.col, r.start.row);
 		if (cell == NULL)
 			return NULL;
-		cell_eval (cell);
+		gnm_cell_eval (cell);
 		v = cell->value;
-		format = cell_get_format (cell);
+		format = gnm_cell_get_format (cell);
 		date_conv = workbook_date_conv (start_sheet->workbook);
 	} else if (v->type == VALUE_ARRAY)
 		v = value_area_get_x_y (v, i, j, &ep);
@@ -1076,10 +1096,10 @@ GSF_CLASS (GnmGODataMatrix, gnm_go_data_matrix,
 	   GO_DATA_MATRIX_TYPE)
 
 GOData *
-gnm_go_data_matrix_new_expr (Sheet *sheet, GnmExpr const *expr)
+gnm_go_data_matrix_new_expr (Sheet *sheet, GnmExprTop const *texpr)
 {
 	GnmGODataMatrix *res = g_object_new (gnm_go_data_matrix_get_type (), NULL);
-	res->dep.expression = expr;
+	res->dep.texpr = texpr;
 	res->dep.sheet = sheet;
 	return GO_DATA (res);
 }
