@@ -15,7 +15,8 @@
 #include "command-context-stderr.h"
 #include "selection.h"
 #include "application.h"
-#include "workbook-control-gui-priv.h"
+#include "workbook-control.h"
+#include "wbc-gtk.h"
 #include "workbook-priv.h"
 #include "workbook.h"
 #include "workbook-view.h"
@@ -45,7 +46,7 @@
 #include <unistd.h>
 
 typedef struct {
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	GnmPasteTarget        *paste_target;
 	GdkAtom            image_atom;
 	GdkAtom            string_atom;
@@ -72,8 +73,8 @@ typedef struct {
 
 
 static GnmCellRegion *
-text_to_cell_region (WorkbookControlGUI *wbcg,
-		     guchar const *data, int data_len,
+text_to_cell_region (WBCGtk *wbcg,
+		     gchar const *data, int data_len,
 		     char const *opt_encoding,
 		     gboolean fixed_encoding)
 {
@@ -154,7 +155,7 @@ text_content_received (GtkClipboard *clipboard,  GtkSelectionData *sel,
 		       gpointer closure)
 {
 	GnmGtkClipboardCtxt *ctxt = closure;
-	WorkbookControlGUI *wbcg = ctxt->wbcg;
+	WBCGtk *wbcg = ctxt->wbcg;
 	WorkbookControl	   *wbc  = WORKBOOK_CONTROL (wbcg);
 	GnmPasteTarget	   *pt   = ctxt->paste_target;
 	GnmCellRegion *content = NULL;
@@ -163,17 +164,17 @@ text_content_received (GtkClipboard *clipboard,  GtkSelectionData *sel,
 	if (sel->length < 0) {
 		;
 	} else if (sel->target == gdk_atom_intern (UTF8_ATOM_NAME, FALSE)) {
-		content = text_to_cell_region (wbcg, sel->data, sel->length, "UTF-8", TRUE);
+		content = text_to_cell_region (wbcg, (const char *)sel->data, sel->length, "UTF-8", TRUE);
 	} else if (sel->target == gdk_atom_intern (CTEXT_ATOM_NAME, FALSE)) {
 		/* COMPOUND_TEXT is icky.  Just let GTK+ do the work.  */
-		char *data_utf8 = gtk_selection_data_get_text (sel);
+		char *data_utf8 = (char *)gtk_selection_data_get_text (sel);
 		content = text_to_cell_region (wbcg, data_utf8, strlen (data_utf8), "UTF-8", TRUE);
 		g_free (data_utf8);
 	} else if (sel->target == gdk_atom_intern (STRING_ATOM_NAME, FALSE)) {
 		char const *locale_encoding;
 		g_get_charset (&locale_encoding);
 
-		content = text_to_cell_region (wbcg, sel->data, sel->length, locale_encoding, FALSE);
+		content = text_to_cell_region (wbcg, (const char *)sel->data, sel->length, locale_encoding, FALSE);
 	}
 	if (content) {
 		/*
@@ -253,7 +254,7 @@ image_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 			  gpointer closure)
 {
 	GnmGtkClipboardCtxt *ctxt = closure;
-	WorkbookControlGUI *wbcg = ctxt->wbcg;
+	WBCGtk *wbcg = ctxt->wbcg;
 	GnmPasteTarget	   *pt   = ctxt->paste_target;
 
 	if (sel->length > 0) {
@@ -275,7 +276,7 @@ table_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 			gpointer closure)
 {
 	GnmGtkClipboardCtxt *ctxt = closure;
-	WorkbookControlGUI *wbcg = ctxt->wbcg;
+	WBCGtk *wbcg = ctxt->wbcg;
 	WorkbookControl	   *wbc  = WORKBOOK_CONTROL (wbcg);
 	GnmPasteTarget	   *pt   = ctxt->paste_target;
 	GnmCellRegion *content = NULL;
@@ -287,7 +288,7 @@ table_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 						   FALSE)) {
 		/* The data is the gnumeric specific XML interchange format */
 		content = xml_cellregion_read (wbc, pt->sheet,
-					       sel->data, sel->length);
+					       (const char *)sel->data, sel->length);
 	} else if ((sel->target == gdk_atom_intern (OOO_ATOM_NAME, FALSE)) ||
 		   (sel->target == gdk_atom_intern (OOO11_ATOM_NAME, FALSE))) {
 		content = table_cellregion_read (wbc, "Gnumeric_OpenCalc:openoffice",
@@ -727,7 +728,7 @@ x_clipboard_clear_cb (GtkClipboard *clipboard,
 }
 
 void
-x_request_clipboard (WorkbookControlGUI *wbcg, GnmPasteTarget const *pt)
+x_request_clipboard (WBCGtk *wbcg, GnmPasteTarget const *pt)
 {
 	GnmGtkClipboardCtxt *ctxt;
 	GdkDisplay *display = gtk_widget_get_display (GTK_WIDGET (wbcg_toplevel (wbcg)));
@@ -778,7 +779,7 @@ target_list_to_entries (GtkTargetList *target_list, int *n_entries)
 }
 
 gboolean
-x_claim_clipboard (WorkbookControlGUI *wbcg)
+x_claim_clipboard (WBCGtk *wbcg)
 {
 	GdkDisplay *display = gtk_widget_get_display (GTK_WIDGET (wbcg_toplevel (wbcg)));
 	GnmCellRegion *content = gnm_app_clipboard_contents_get ();
@@ -864,14 +865,14 @@ void
 x_store_clipboard_if_needed (Workbook *wb)
 {
 	Sheet *sheet = gnm_app_clipboard_sheet_get ();
-	WorkbookControlGUI *wbcg = NULL;
+	WBCGtk *wbcg = NULL;
 
 	g_return_if_fail (IS_WORKBOOK (wb));
 	
 	if (sheet && sheet->workbook == wb) {
 		WORKBOOK_FOREACH_CONTROL (wb, view, control, {
-			if (IS_WORKBOOK_CONTROL_GUI (control)) {
-				wbcg = WORKBOOK_CONTROL_GUI (control);
+			if (IS_WBC_GTK (control)) {
+				wbcg = WBC_GTK (control);
 			}
 		});
 
