@@ -12,7 +12,6 @@
 #include "libgnumeric.h"
 #include "gui-util.h"
 
-#include "workbook-control-gui-priv.h"
 #include "gutils.h"
 #include "parse-util.h"
 #include "style.h"
@@ -23,6 +22,8 @@
 #include "application.h"
 #include "workbook.h"
 #include "libgnumeric.h"
+#include "wbc-gtk.h"
+#include "widgets/gnumeric-expr-entry.h"
 
 #include <goffice/app/error-info.h>
 #include <goffice/gtk/go-combo-color.h>
@@ -146,7 +147,7 @@ gnumeric_error_info_dialog_show (GtkWindow *parent, ErrorInfo *error)
 }
 
 typedef struct {
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	GtkWidget	   *dialog;
 	char const *key;
 	gboolean freed;
@@ -182,7 +183,7 @@ cb_keyed_dialog_keypress (GtkWidget *dialog, GdkEventKey *event,
 /**
  * gnumeric_keyed_dialog
  *
- * @wbcg    A WorkbookControlGUI
+ * @wbcg    A WBCGtk
  * @dialog  A transient window
  * @key     A key to identify the dialog
  *
@@ -192,11 +193,11 @@ cb_keyed_dialog_keypress (GtkWidget *dialog, GdkEventKey *event,
  * the object data is managed here.
  **/
 void
-gnumeric_keyed_dialog (WorkbookControlGUI *wbcg, GtkWindow *dialog, char const *key)
+gnumeric_keyed_dialog (WBCGtk *wbcg, GtkWindow *dialog, char const *key)
 {
 	KeyedDialogContext *ctxt;
 
-	g_return_if_fail (IS_WORKBOOK_CONTROL_GUI (wbcg));
+	g_return_if_fail (IS_WBC_GTK (wbcg));
 	g_return_if_fail (GTK_IS_WINDOW (dialog));
 	g_return_if_fail (key != NULL);
 
@@ -221,14 +222,14 @@ gnumeric_keyed_dialog (WorkbookControlGUI *wbcg, GtkWindow *dialog, char const *
 /**
  * gnumeric_dialog_raise_if_exists
  *
- * @wbcg    A WorkbookControlGUI
+ * @wbcg    A WBCGtk
  * @key     A key to identify the dialog
  *
  * Raise the dialog identified by key if it is registered on the wbcg.
  * Returns TRUE if dialog found, FALSE if not.
  **/
 gpointer
-gnumeric_dialog_raise_if_exists (WorkbookControlGUI *wbcg, char const *key)
+gnumeric_dialog_raise_if_exists (WBCGtk *wbcg, char const *key)
 {
 	KeyedDialogContext *ctxt;
 
@@ -774,7 +775,8 @@ gnm_pixbuf_tile (GdkPixbuf const *src, int w, int h)
 	GdkPixbuf *dst = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (src),
 					 gdk_pixbuf_get_has_alpha (src),
 					 gdk_pixbuf_get_bits_per_sample (src),
-					 w, h);
+					 MAX (w, 1),
+					 MAX (h, 1));
 
 	for (stripe_y = -1; stripe_y <= tile_y; stripe_y++) {
 		int dst_x = 0;
@@ -982,3 +984,94 @@ gnm_tree_model_iter_prev (GtkTreeModel *model, GtkTreeIter* iter)
 	gtk_tree_path_free (path);
 	return FALSE;
 }
+
+typedef struct {
+	GPtrArray *objects_signals;
+} GnmDialogDestroySignals;
+
+static void
+cb_gnm_dialog_setup_destroy_handlers (G_GNUC_UNUSED GtkWidget *widget,
+				      GnmDialogDestroySignals *dd)
+{
+	GPtrArray *os = dd->objects_signals;
+	int i;
+
+	for (i = 0; i < (int)os->len; i += 2) {
+		GObject *obj = g_ptr_array_index (os, i);
+		guint s = GPOINTER_TO_UINT (g_ptr_array_index (os, i + 1));
+		g_signal_handler_disconnect (obj, s);	
+	}
+
+	g_ptr_array_free (os, TRUE);
+	memset (dd, 0, sizeof (*dd));
+	g_free (dd);
+}
+
+void
+gnm_dialog_setup_destroy_handlers (GtkDialog *dialog,
+				   WBCGtk *wbcg,
+				   GnmDialogDestroyOptions what)
+{
+	GnmDialogDestroySignals *dd = g_new (GnmDialogDestroySignals, 1);
+	Workbook *wb = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
+	Sheet *sheet = wb_control_cur_sheet (WORKBOOK_CONTROL (wbcg));
+	int N = workbook_sheet_count (wb), i;
+	GPtrArray *os = g_ptr_array_new ();
+
+	dd->objects_signals = os;
+
+	/* FIXME: Properly implement CURRENT_SHEET_REMOVED.  */
+	if (what & GNM_DIALOG_DESTROY_CURRENT_SHEET_REMOVED)
+		what |= GNM_DIALOG_DESTROY_SHEET_REMOVED;
+
+	if (what & GNM_DIALOG_DESTROY_SHEET_REMOVED) {
+		guint s = g_signal_connect_swapped
+			(G_OBJECT (wb),
+			 "sheet_deleted",
+			 G_CALLBACK (gtk_widget_destroy),
+			 dialog);
+		g_ptr_array_add (os, wb);
+		g_ptr_array_add (os, GUINT_TO_POINTER (s));
+	}
+
+	if (what & GNM_DIALOG_DESTROY_SHEET_ADDED) {
+		guint s = g_signal_connect_swapped
+			(G_OBJECT (wb),
+			 "sheet_added",
+			 G_CALLBACK (gtk_widget_destroy),
+			 dialog);
+		g_ptr_array_add (os, wb);
+		g_ptr_array_add (os, GUINT_TO_POINTER (s));
+	}
+
+	if (what & GNM_DIALOG_DESTROY_SHEETS_REORDERED) {
+		guint s = g_signal_connect_swapped
+			(G_OBJECT (wb),
+			 "sheet_order_changed",
+			 G_CALLBACK (gtk_widget_destroy),
+			 dialog);
+		g_ptr_array_add (os, wb);
+		g_ptr_array_add (os, GUINT_TO_POINTER (s));
+	}
+
+	for (i = 0; i < N; i++) {
+		Sheet *this_sheet = workbook_sheet_by_index (wb, i);
+		gboolean current = (sheet == this_sheet);
+
+		if ((what & GNM_DIALOG_DESTROY_SHEET_RENAMED) ||
+		    (current && (what & GNM_DIALOG_DESTROY_CURRENT_SHEET_RENAMED))) {
+			guint s = g_signal_connect_swapped
+				(G_OBJECT (this_sheet),
+				 "notify::name",
+				 G_CALLBACK (gtk_widget_destroy),
+				 dialog);
+			g_ptr_array_add (os, this_sheet);
+			g_ptr_array_add (os, GUINT_TO_POINTER (s));
+		}
+	}
+
+	g_signal_connect (G_OBJECT (dialog),
+			  "destroy",
+			  G_CALLBACK (cb_gnm_dialog_setup_destroy_handlers),
+			  dd);
+}
