@@ -8,17 +8,18 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "item-bar.h"
+#include "gnm-pane-impl.h"
 
 #include "style-color.h"
 #include "sheet.h"
+#include "sheet-control-gui.h"
 #include "sheet-control-gui-priv.h"
 #include "application.h"
 #include "selection.h"
-#include "gnumeric-canvas.h"
-#include "workbook-edit.h"
+#include "wbc-gtk.h"
 #include "gui-util.h"
 #include "parse-util.h"
 #include "commands.h"
@@ -33,7 +34,7 @@
 struct _ItemBar {
 	FooCanvasItem	 base;
 
-	GnmCanvas	*gcanvas;
+	GnmPane		*pane;
 	GdkGC           *text_gc, *filter_gc, *lines, *shade;
 	GdkCursor       *normal_cursor;
 	GdkCursor       *change_cursor;
@@ -60,7 +61,7 @@ static FooCanvasItemClass *parent_class;
 
 enum {
 	ITEM_BAR_PROP_0,
-	ITEM_BAR_PROP_GNUMERIC_CANVAS,
+	ITEM_BAR_PROP_PANE,
 	ITEM_BAR_PROP_IS_COL_HEADER
 };
 
@@ -103,20 +104,20 @@ ib_fonts_unref (ItemBar *ib)
 int
 item_bar_calc_size (ItemBar *ib)
 {
-	SheetControlGUI	* const scg = ib->gcanvas->simple.scg;
-	Sheet const *sheet = ((SheetControl *) scg)->sheet;
+	SheetControlGUI	* const scg = ib->pane->simple.scg;
+	Sheet const *sheet = scg_sheet (scg);
 	double const zoom_factor = sheet->last_zoom_factor_used;
 	PangoContext *context;
-	const PangoFontDescription *src_desc = wbcg_get_font_desc (scg->wbcg);
+	PangoFontDescription const *src_desc = wbcg_get_font_desc (scg_wbcg (scg));
 	PangoFontDescription *desc;
 	int size = pango_font_description_get_size (src_desc);
 	PangoLayout *layout;
 	PangoRectangle ink_rect, logical_rect;
-	gboolean const char_label = ib->is_col_header && !sheet->r1c1_addresses;
+	gboolean const char_label = ib->is_col_header && !sheet->convs->r1c1_addresses;
 
 	ib_fonts_unref (ib);
 
-	context = gtk_widget_get_pango_context (GTK_WIDGET (ib->gcanvas));
+	context = gtk_widget_get_pango_context (GTK_WIDGET (ib->pane));
 	desc = pango_font_description_copy (src_desc);
 	pango_font_description_set_size (desc, zoom_factor * size);
 	layout = pango_layout_new (context);
@@ -156,9 +157,11 @@ item_bar_calc_size (ItemBar *ib)
 	g_object_unref (layout);
 
 	ib->pango.item->analysis.font = g_object_ref (ib->normal_font);
+	ib->pango.item->analysis.language =
+		pango_context_get_language (context);
 	ib->pango.item->analysis.shape_engine =
 		pango_font_find_shaper (ib->normal_font,
-					pango_context_get_language (context),
+					ib->pango.item->analysis.language,
 					'A');
 
 	ib->indent = ib_compute_pixels_from_indent (sheet, ib->is_col_header);
@@ -288,11 +291,13 @@ ib_draw_cell (ItemBar const * const ib, GdkDrawable *drawable,
 	}
 	g_return_if_fail (font != NULL);
 
+	/* Draw header background */
 	gdk_draw_rectangle (drawable, gc, TRUE,
-			    rect->x + 1, rect->y + 1, rect->width-2, rect->height-2);
+			    rect->x + 1, rect->y + 1, rect->width - 1, rect->height - 1);
+	/* Then draw its shadow. */
 	gtk_paint_shadow (canvas->style, drawable, GTK_STATE_NORMAL, shadow,
 			  NULL, NULL, "GnmItemBarCell",
-			  rect->x, rect->y, rect->width, rect->height);
+			  rect->x, rect->y, rect->width + 1, rect->height + 1);
 	gdk_gc_set_clip_rectangle (text_gc, rect);
 
 	g_object_unref (ib->pango.item->analysis.font);
@@ -315,10 +320,10 @@ static void
 item_bar_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expose)
 {
 	ItemBar const         *ib = ITEM_BAR (item);
-	GnmCanvas const	      *gcanvas = ib->gcanvas;
-	SheetControlGUI const *scg    = gcanvas->simple.scg;
-	Sheet const           *sheet  = ((SheetControl *) scg)->sheet;
-	SheetView const	      *sv     = ((SheetControl *) scg)->view;
+	GnmPane	 const	      *pane = ib->pane;
+	SheetControlGUI const *scg    = pane->simple.scg;
+	Sheet const           *sheet  = scg_sheet (scg);
+	SheetView const	      *sv     = scg_view (scg);
 	GtkWidget *canvas = GTK_WIDGET (item->canvas);
 	ColRowInfo const *cri, *next = NULL;
 	int pixels;
@@ -338,8 +343,8 @@ item_bar_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expos
 		int const base_pos = .2 * inc;
 		int const len = (inc > 4) ? 4 : inc;
 		int end = expose->area.x;
-		int total, col = gcanvas->first.col;
-		gboolean const char_label = !sheet->r1c1_addresses;
+		int total, col = pane->first.col;
+		gboolean const char_label = !sheet->convs->r1c1_addresses;
 
 		/* shadow type selection must be keep in sync with code in ib_draw_cell */
 		rect.y = ib->indent;
@@ -347,15 +352,11 @@ item_bar_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expos
 		shadow = (col > 0 && !has_object && sv_selection_col_type (sv, col-1) == COL_ROW_FULL_SELECTION) 
 			? GTK_SHADOW_IN : GTK_SHADOW_OUT;
 
-		if (rtl) {
-			total = gnm_simple_canvas_x_w2c (item->canvas, gcanvas->first_offset.col) + 2;
-			gtk_paint_shadow (canvas->style, drawable, GTK_STATE_NORMAL, shadow,
-				NULL, NULL, "GnmItemBarCell", total-2, rect.y, 10, rect.height);
-		} else {
-			total = gcanvas->first_offset.col+1;
+		if (rtl)
+			total = gnm_foo_canvas_x_w2c (item->canvas, pane->first_offset.col);
+		else {
+			total = pane->first_offset.col;
 			end += expose->area.width;
-			gtk_paint_shadow (canvas->style, drawable, GTK_STATE_NORMAL, shadow,
-				NULL, NULL, "GnmItemBarCell", total-10, rect.y, 10, rect.height);
 		}
 
 		if (col > 0) {
@@ -510,34 +511,17 @@ item_bar_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expos
 		int const end = expose->area.y + expose->area.height;
 		int const dir = rtl ? -1 : 1;
 
-		int total = 1 + gcanvas->first_offset.row;
-		int row = gcanvas->first.row;
+		int total = pane->first_offset.row;
+		int row = pane->first.row;
 
 		if (rtl) {
 			base_pos = ib->indent + ib->cell_width - base_pos;
-			rect.x = 0;
+			/* Move header bar 1 pixel to the left. */
+			rect.x = -1;
 		} else
 			rect.x = ib->indent;
 		rect.width = ib->cell_width;
 
-		/* To avoid overlaping the cells the shared pixel belongs to
-		 * the cell above.  This has the nice property that the bottom
-		 * dark line of the shadow aligns with the grid lines.
-		 * Unfortunately it also implies a 1 pixel empty space at the
-		 * top of the bar.  Which we are forced to fill in with
-		 * something.  For now we draw a shadow there to be compatible 
-		 * with the colour used on the bottom of the cell shadows.
-		 *
-		 * shadow type selection must be keep in sync with code in ib_draw_cell.
-		 */
-		if (row > 0 && !has_object && sv_selection_row_type (sv, row - 1) == COL_ROW_FULL_SELECTION)
-			shadow = GTK_SHADOW_IN;
-		else 
-			shadow = GTK_SHADOW_OUT;
-		gtk_paint_shadow (canvas->style, drawable, GTK_STATE_NORMAL, shadow,
-				  NULL, NULL, "GnmItemBarCell",
-				  rect.x, total-10, rect.width, 10);
-
 		if (row > 0) {
 			cri = sheet_row_get_info (sheet, row-1);
 			prev_visible = cri->visible;
@@ -700,7 +684,7 @@ item_bar_point (FooCanvasItem *item, double x, double y, int cx, int cy,
  * @minor_pos :
  *
  * NOTE : this could easily be optimized.  We need not start at 0 every time.
- *        We could potentially use the routines in gnumeric-canvas.
+ *        We could potentially use the routines in gnm-pane.
  *
  * Returns non-NULL if point (@x,@y) is on a division
  **/
@@ -708,7 +692,7 @@ static ColRowInfo const *
 is_pointer_on_division (ItemBar const *ib, double x, double y,
 			int *the_total, int *the_element, int *minor_pos)
 {
-	Sheet *sheet = sc_sheet (SHEET_CONTROL (ib->gcanvas->simple.scg));
+	Sheet *sheet = scg_sheet (ib->pane->simple.scg);
 	ColRowInfo const *cri;
 	double const scale = ib->base.canvas->pixels_per_unit;
 	int major, minor, i, total = 0;
@@ -740,10 +724,11 @@ is_pointer_on_division (ItemBar const *ib, double x, double y,
 		}
 
 		if (cri->visible) {
+			WBCGtk *wbcg = scg_wbcg (ib->pane->simple.scg);
 			total += cri->size_pixels;
 
-			if (wbcg_edit_get_guru (ib->gcanvas->simple.scg->wbcg) == NULL &&
-			    !wbcg_is_editing (ib->gcanvas->simple.scg->wbcg) &&
+			if (wbcg_edit_get_guru (wbcg) == NULL &&
+			    !wbcg_is_editing (wbcg) &&
 			    (total - 4 < major) && (major < total + 4)) {
 				if (the_total)
 					*the_total = total;
@@ -798,12 +783,12 @@ static void
 item_bar_resize_stop (ItemBar *ib, int new_size)
 {
 	if (new_size != 0 && ib->colrow_being_resized >= 0)
-		scg_colrow_size_set (ib->gcanvas->simple.scg,
+		scg_colrow_size_set (ib->pane->simple.scg,
 				     ib->is_col_header,
 				     ib->colrow_being_resized, new_size);
 	ib->colrow_being_resized = -1;
 	ib->has_resize_guides = FALSE;
-	scg_colrow_resize_stop (ib->gcanvas->simple.scg);
+	scg_size_guide_stop (ib->pane->simple.scg);
 
 	if (ib->tip != NULL) {
 		gtk_widget_destroy (gtk_widget_get_toplevel (ib->tip));
@@ -812,21 +797,20 @@ item_bar_resize_stop (ItemBar *ib, int new_size)
 }
 
 static gboolean
-cb_extend_selection (GnmCanvas *gcanvas,
-		     int col, int row, gpointer user_data)
+cb_extend_selection (GnmPane *pane, GnmPaneSlideInfo const *info)
 {
-	ItemBar * const ib = user_data;
+	ItemBar * const ib = info->user_data;
 	gboolean const is_cols = ib->is_col_header;
-	scg_colrow_select (gcanvas->simple.scg,
-			   is_cols, is_cols ? col : row, GDK_SHIFT_MASK);
+	scg_colrow_select (pane->simple.scg,
+		is_cols, is_cols ? info->col : info->row, GDK_SHIFT_MASK);
 	return TRUE;
 }
 
 static gint
 outline_button_press (ItemBar const *ib, int element, int pixel)
 {
-	SheetControl *sc = (SheetControl *) ib->gcanvas->simple.scg;
-	Sheet * const sheet = sc->sheet;
+	SheetControlGUI *scg = ib->pane->simple.scg;
+	Sheet * const sheet = scg_sheet (scg);
 	int inc, step;
 
 	if (ib->is_col_header) {
@@ -841,7 +825,8 @@ outline_button_press (ItemBar const *ib, int element, int pixel)
 
 	step = pixel / inc;
 
-	cmd_selection_outline_change (sc->wbc, ib->is_col_header, element, step);
+	cmd_selection_outline_change (scg_wbc (scg), ib->is_col_header,
+				      element, step);
 	return TRUE;
 }
 
@@ -851,11 +836,11 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 	ColRowInfo const *cri;
 	FooCanvas	* const canvas = item->canvas;
 	ItemBar		* const ib = ITEM_BAR (item);
-	GnmCanvas	* const gcanvas = ib->gcanvas;
-	SheetControlGUI	* const scg = gcanvas->simple.scg;
-	SheetControl	* const sc = (SheetControl *) gcanvas->simple.scg;
-	Sheet		* const sheet = sc->sheet;
-	WorkbookControlGUI * const wbcg = scg->wbcg;
+	GnmPane		* const pane = ib->pane;
+	SheetControlGUI	* const scg = pane->simple.scg;
+	SheetControl	* const sc = (SheetControl *) pane->simple.scg;
+	Sheet		* const sheet = sc_sheet (sc);
+	WBCGtk * const wbcg = scg_wbcg (scg);
 	gboolean const is_cols = ib->is_col_header;
 	int pos, minor_pos, start, element, x, y;
 
@@ -876,15 +861,12 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 			int new_size;
 			if (!ib->has_resize_guides) {
 				ib->has_resize_guides = TRUE;
-				scg_colrow_resize_start	(ib->gcanvas->simple.scg,
-							 ib->is_col_header,
-							 ib->colrow_being_resized);
+				scg_size_guide_start (ib->pane->simple.scg,
+					ib->is_col_header, ib->colrow_being_resized, 1);
 
 				gnm_simple_canvas_grab (item,
-					GDK_POINTER_MOTION_MASK |
-					GDK_BUTTON_RELEASE_MASK,
-					ib->change_cursor,
-					e->motion.time);
+					GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
+					ib->change_cursor, e->motion.time);
 			}
 
 			cri = sheet_colrow_get_info (sheet,
@@ -896,34 +878,39 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 				new_size += cri->size_pixels;
 
 			/* Ensure we always have enough room for the margins */
-			if (new_size <= (cri->margin_a + cri->margin_b)) {
-				new_size = cri->margin_a + cri->margin_b + 1;
-				if (is_cols)
-					pos = gcanvas->first_offset.col +
+			if (is_cols) {
+				if (new_size <= (GNM_COL_MARGIN + GNM_COL_MARGIN)) {
+					new_size = GNM_COL_MARGIN + GNM_COL_MARGIN + 1;
+					pos = pane->first_offset.col +
 						scg_colrow_distance_get (scg, TRUE,
-							gcanvas->first.col,
+							pane->first.col,
 							ib->colrow_being_resized);
-				else
-					pos = gcanvas->first_offset.row +
+					pos += new_size;
+				}
+			} else {
+				if (new_size <= (GNM_ROW_MARGIN + GNM_ROW_MARGIN)) {
+					new_size = GNM_ROW_MARGIN + GNM_ROW_MARGIN + 1;
+					pos = pane->first_offset.row +
 						scg_colrow_distance_get (scg, FALSE,
-							gcanvas->first.row,
+							pane->first.row,
 							ib->colrow_being_resized);
-				pos += new_size;
+					pos += new_size;
+				}
 			}
 
 			ib->colrow_resize_size = new_size;
 			colrow_tip_setlabel (ib, is_cols, new_size);
-			scg_colrow_resize_move (scg, is_cols, pos);
+			scg_size_guide_motion (scg, is_cols, pos);
 
 			/* Redraw the ItemBar to show nice incremental progress */
 			foo_canvas_request_redraw (canvas, 0, 0, G_MAXINT/2,  G_MAXINT/2);
 
 		} else if (ib->start_selection != -1) {
 
-			gnm_canvas_handle_motion (ib->gcanvas,
+			gnm_pane_handle_motion (ib->pane,
 				canvas, &e->motion,
-				GNM_CANVAS_SLIDE_AT_COLROW_BOUND |
-					(is_cols ? GNM_CANVAS_SLIDE_X : GNM_CANVAS_SLIDE_Y),
+				GNM_PANE_SLIDE_AT_COLROW_BOUND |
+					(is_cols ? GNM_PANE_SLIDE_X : GNM_PANE_SLIDE_Y),
 				cb_extend_selection, ib);
 		} else
 			ib_set_cursor (ib, e->motion.x, e->motion.y);
@@ -935,7 +922,7 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 			return FALSE;
 
 		if (wbcg_edit_get_guru (wbcg) == NULL)
-			scg_mode_edit (sc);
+			scg_mode_edit (scg);
 
 		cri = is_pointer_on_division (ib, e->button.x, e->button.y,
 			&start, &element, &minor_pos);
@@ -950,7 +937,7 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 			/* If the selection does not contain the current row/col
 			 * then clear the selection and add it.
 			 */
-			if (!sv_is_colrow_selected (sc->view, element, is_cols))
+			if (!sv_is_colrow_selected (sc_view (sc), element, is_cols))
 				scg_colrow_select (scg, is_cols,
 						   element, e->button.state);
 
@@ -982,7 +969,7 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 			}
 		} else {
 			if (wbcg_edit_get_guru (wbcg) != NULL &&
-			    !wbcg_edit_entry_redirect_p (wbcg))
+			    !wbcg_entry_has_logical (wbcg))
 				break;
 
 			/* If we're editing it is possible for this to fail */
@@ -990,7 +977,7 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 				break;
 
 			ib->start_selection = element;
-			gnm_canvas_slide_init (gcanvas);
+			gnm_pane_slide_init (pane);
 			gnm_simple_canvas_grab (item,
 				GDK_POINTER_MOTION_MASK |
 				GDK_BUTTON_RELEASE_MASK,
@@ -1016,13 +1003,13 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 		if (e->button.button > 3)
 			return FALSE;
 
-		gnm_canvas_slide_stop (ib->gcanvas);
+		gnm_pane_slide_stop (ib->pane);
 
 		if (ib->start_selection >= 0) {
 			needs_ungrab = TRUE;
 			ib->start_selection = -1;
 			gnm_expr_entry_signal_update (
-				wbcg_get_entry_logical (scg->wbcg), TRUE);
+				wbcg_get_entry_logical (wbcg), TRUE);
 		}
 		if (ib->colrow_being_resized >= 0) {
 			if (ib->has_resize_guides) {
@@ -1053,8 +1040,8 @@ item_bar_set_property (GObject *obj, guint param_id,
 	ItemBar *ib = ITEM_BAR (obj);
 
 	switch (param_id){
-	case ITEM_BAR_PROP_GNUMERIC_CANVAS:
-		ib->gcanvas = g_value_get_object (value);
+	case ITEM_BAR_PROP_PANE:
+		ib->pane = g_value_get_object (value);
 		break;
 	case ITEM_BAR_PROP_IS_COL_HEADER:
 		ib->is_col_header = g_value_get_boolean (value);
@@ -1064,7 +1051,7 @@ item_bar_set_property (GObject *obj, guint param_id,
 }
 
 static void
-item_bar_finalize (GObject *obj)
+item_bar_dispose (GObject *obj)
 {
 	ItemBar *ib = ITEM_BAR (obj);
 
@@ -1084,7 +1071,7 @@ item_bar_finalize (GObject *obj)
 		ib->pango.item = NULL;
 	}
 
-	(*G_OBJECT_CLASS (parent_class)->finalize) (obj);
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
@@ -1107,7 +1094,7 @@ item_bar_init (ItemBar *ib)
 
 	ib->colrow_being_resized = -1;
 	ib->has_resize_guides = FALSE;
-	ib->pango.item   = pango_item_new ();
+	ib->pango.item = pango_item_new ();
 	ib->pango.glyphs = pango_glyph_string_new ();
 }
 
@@ -1118,12 +1105,12 @@ item_bar_class_init (GObjectClass  *gobject_klass)
 
 	parent_class = g_type_class_peek_parent (gobject_klass);
 
-	gobject_klass->finalize     = item_bar_finalize;
+	gobject_klass->dispose = item_bar_dispose;
 	gobject_klass->set_property = item_bar_set_property;
-	g_object_class_install_property (gobject_klass, ITEM_BAR_PROP_GNUMERIC_CANVAS,
-		g_param_spec_object ("GnumericCanvas", "GnumericCanvas",
-			"the canvas of the associated grid",
-			GNM_CANVAS_TYPE,
+	g_object_class_install_property (gobject_klass, ITEM_BAR_PROP_PANE,
+		g_param_spec_object ("pane", "pane",
+			"The pane containing the associated grid",
+			GNM_PANE_TYPE,
 			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_klass, ITEM_BAR_PROP_IS_COL_HEADER,
 		g_param_spec_boolean ("IsColHeader", "IsColHeader",
