@@ -11,10 +11,9 @@
 #include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "item-cursor.h"
+#include "gnm-pane-impl.h"
 
-#include "gnumeric-canvas.h"
 #include "sheet-control-gui.h"
-#include "gnumeric-pane.h"
 #include "style-color.h"
 #include "cell.h"
 #include "clipboard.h"
@@ -24,7 +23,7 @@
 #include "sheet-merge.h"
 #include "value.h"
 #include "workbook.h"
-#include "workbook-edit.h"
+#include "wbc-gtk.h"
 #include "gui-util.h"
 #include "cmd-edit.h"
 #include "commands.h"
@@ -74,7 +73,9 @@ struct _ItemCursor {
 	GnmRange autofill_src;
 	int   autofill_hsize, autofill_vsize;
 
-	struct { /* cursor outline in canvas coords (bounding box is larger) */
+	/* cursor outline in canvas coords, the bounding box (Item::[xy][01])
+	 * is slightly larger ) */
+	struct {
 		int x1, x2, y1, y2;
 	} outline;
 	int drag_button;
@@ -150,9 +151,6 @@ item_cursor_realize (FooCanvasItem *item)
 	}
 }
 
-/*
- * Release all of the resources we allocated
- */
 static void
 item_cursor_unrealize (FooCanvasItem *item)
 {
@@ -178,25 +176,24 @@ item_cursor_unrealize (FooCanvasItem *item)
 static void
 item_cursor_update (FooCanvasItem *item, double i2w_dx, double i2w_dy, int flags)
 {
-	ItemCursor    *ic = ITEM_CURSOR (item);
-	GnmCanvas *gcanvas = GNM_CANVAS (item->canvas);
+	ItemCursor	*ic = ITEM_CURSOR (item);
+	GnmPane		*pane = GNM_PANE (item->canvas);
 	SheetControlGUI const * const scg = ic->scg;
 	int tmp;
 
-	/* Clip the bounds of the cursor to the visible region of cells */
-	int const left = MAX (gcanvas->first.col-1, ic->pos.start.col);
-	int const right = MIN (gcanvas->last_visible.col+1, ic->pos.end.col);
-	int const top = MAX (gcanvas->first.row-1, ic->pos.start.row);
-	int const bottom = MIN (gcanvas->last_visible.row+1, ic->pos.end.row);
+	int const left	 = ic->pos.start.col;
+	int const right	 = ic->pos.end.col;
+	int const top	 = ic->pos.start.row;
+	int const bottom = ic->pos.end.row;
 
 	foo_canvas_item_request_redraw (item); /* Erase the old cursor */
 
-	ic->outline.x1 = gcanvas->first_offset.col +
-		scg_colrow_distance_get (scg, TRUE, gcanvas->first.col, left);
+	ic->outline.x1 = pane->first_offset.col +
+		scg_colrow_distance_get (scg, TRUE, pane->first.col, left);
 	ic->outline.x2 = ic->outline.x1 +
 		scg_colrow_distance_get (scg, TRUE, left, right+1);
-	ic->outline.y1 = gcanvas->first_offset.row +
-		scg_colrow_distance_get (scg, FALSE, gcanvas->first.row, top);
+	ic->outline.y1 = pane->first_offset.row +
+		scg_colrow_distance_get (scg, FALSE, pane->first.row, top);
 	ic->outline.y2 = ic->outline.y1 +
 		scg_colrow_distance_get (scg, FALSE,top, bottom+1);
 
@@ -222,12 +219,6 @@ item_cursor_update (FooCanvasItem *item, double i2w_dx, double i2w_dy, int flags
 		(*parent_class->update) (item, i2w_dx, i2w_dy, flags);
 }
 
-/*
- * Draw an item of this type.  (x, y) are the upper-left canvas pixel
- * coordinates of the drawable, a temporary pixmap, where things get
- * drawn.  (width, height) are the dimensions of the drawable.
- * In other words - a clipping region.
- */
 static void
 item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 		  GdkEventExpose *expose)
@@ -242,8 +233,8 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 	gboolean draw_stippled, draw_center, draw_external, draw_internal;
 
 #if 0
-	fprintf (stderr, "draw[%d] %d,%d %d,%d\n",
-		 GNM_CANVAS (item->canvas)->pane->index, 
+	g_print ("draw[%d] %d,%d %d,%d\n",
+		 GNM_PANE (item->canvas)->index, 
 		 ic->outline.x1,
 		 ic->outline.y1,
 		 ic->outline.x2,
@@ -287,21 +278,21 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 		draw_internal = TRUE;
 		draw_external = TRUE;
 		{
-			GnmCanvas const *gcanvas = GNM_CANVAS (item->canvas);
-			GnmCanvas const *gcanvas0 = scg_pane (gcanvas->simple.scg, 0);
+			GnmPane const *pane = GNM_PANE (item->canvas);
+			GnmPane const *pane0 = scg_pane (pane->simple.scg, 0);
 
 			/* In pane */
-			if (ic->pos.end.row <= gcanvas->last_full.row)
+			if (ic->pos.end.row <= pane->last_full.row)
 				draw_handle = 1;
 			/* In pane below */
-			else if ((gcanvas->pane->index == 2 || gcanvas->pane->index == 3) &&
-				 ic->pos.end.row >= gcanvas0->first.row &&
-				 ic->pos.end.row <= gcanvas0->last_full.row)
+			else if ((pane->index == 2 || pane->index == 3) &&
+				 ic->pos.end.row >= pane0->first.row &&
+				 ic->pos.end.row <= pane0->last_full.row)
 				draw_handle = 1;
 			/* TODO : do we want to add checking for pane above ? */
-			else if (ic->pos.start.row < gcanvas->first.row)
+			else if (ic->pos.start.row < pane->first.row)
 				draw_handle = 0;
-			else if (ic->pos.start.row != gcanvas->first.row)
+			else if (ic->pos.start.row != pane->first.row)
 				draw_handle = 2;
 			else
 				draw_handle = 3;
@@ -338,6 +329,9 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 	x1 = MIN (x1, expose->area.x + expose->area.width + CLIP_SAFETY_MARGIN);
 	y1 = MIN (y1, expose->area.y + expose->area.height + CLIP_SAFETY_MARGIN);
 
+	if (x0 >= x1 || y0 >= y1)
+		draw_handle = 0;
+
 	gdk_gc_set_line_attributes (ic->gc, 1,
 		GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
 	gdk_gc_set_rgb_fg_color (ic->gc, &gs_white);
@@ -472,7 +466,7 @@ item_cursor_bound_set (ItemCursor *ic, GnmRange const *new_bound)
 	g_return_val_if_fail (IS_ITEM_CURSOR (ic), FALSE);
 	g_return_val_if_fail (range_is_sane (new_bound), FALSE);
 
-	if (range_equal (&ic->pos, new_bound) && ic->pos_initialized)
+	if (ic->pos_initialized && range_equal (&ic->pos, new_bound))
 		return FALSE;
 
 	ic->pos = *new_bound;
@@ -488,16 +482,12 @@ item_cursor_bound_set (ItemCursor *ic, GnmRange const *new_bound)
  *
  * When a sheet is zoomed.  The pixel coords shift slightly.  The item cursor
  * must regenerate to stay in sync.
- */
+ **/
 void
 item_cursor_reposition (ItemCursor *ic)
 {
-	FooCanvasItem *item = FOO_CANVAS_ITEM (ic);
-
-	g_return_if_fail (item != NULL);
-
-	/* Request an update */
-	foo_canvas_item_request_update (item);
+	g_return_if_fail (ic != NULL);
+	foo_canvas_item_request_update (&ic->canvas_item);
 }
 
 static double
@@ -599,7 +589,7 @@ static gint
 item_cursor_selection_event (FooCanvasItem *item, GdkEvent *event)
 {
 	FooCanvas  *canvas = item->canvas;
-	GnmCanvas  *gcanvas = GNM_CANVAS (canvas);
+	GnmPane  *pane = GNM_PANE (canvas);
 	ItemCursor *ic = ITEM_CURSOR (item);
 	int x, y;
 
@@ -636,7 +626,7 @@ item_cursor_selection_event (FooCanvasItem *item, GdkEvent *event)
 		gnm_simple_canvas_ungrab (item, event->button.time);
 
 		scg_special_cursor_start (ic->scg, style, button);
-		special_cursor = gcanvas->pane->cursor.special;
+		special_cursor = pane->cursor.special;
 		special_cursor->drag_button_state = ic->drag_button_state;
 		if (style == ITEM_CURSOR_AUTOFILL)
 			item_cursor_setup_auto_fill (
@@ -654,9 +644,9 @@ item_cursor_selection_event (FooCanvasItem *item, GdkEvent *event)
 		 * selection was offset by one.
 		 */
 		{
-			int d_col = gnm_canvas_find_col (gcanvas, x, NULL) -
+			int d_col = gnm_pane_find_col (pane, x, NULL) -
 				ic->pos.start.col;
-			int d_row = gnm_canvas_find_row (gcanvas, y, NULL) -
+			int d_row = gnm_pane_find_row (pane, y, NULL) -
 				ic->pos.start.row;
 
 			if (d_col >= 0) {
@@ -682,7 +672,7 @@ item_cursor_selection_event (FooCanvasItem *item, GdkEvent *event)
 		gnm_simple_canvas_grab (FOO_CANVAS_ITEM (special_cursor),
 			GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK,
 			NULL, event->button.time);
-		gnm_canvas_slide_init (gcanvas);
+		gnm_pane_slide_init (pane);
 
 		/*
 		 * We flush after the grab to ensure that the new item-cursor
@@ -1049,9 +1039,6 @@ item_cursor_popup_menu (ItemCursor *ic, GdkEventButton *event)
 				    0, 0, event);
 }
 
-/*
- * Invoked when the item has been dropped
- */
 static void
 item_cursor_do_drop (ItemCursor *ic, GdkEventButton *event)
 {
@@ -1073,33 +1060,6 @@ item_cursor_do_drop (ItemCursor *ic, GdkEventButton *event)
 				       : ACTION_MOVE_CELLS);
 }
 
-static void
-item_cursor_set_bounds_visibly (ItemCursor *ic,
-				int visible_col,int visible_row,
-				GnmCellPos const *corner,
-				int end_col, int end_row)
-{
-	FooCanvasItem *item = FOO_CANVAS_ITEM (ic);
-	GnmCanvas  *gcanvas = GNM_CANVAS (item->canvas);
-	GnmRange r;
-
-	/* Handle visibility here rather than in the slide handler because we
-	 * need to constrain movement some times.  eg no sense scrolling the
-	 * canvas if the autofill cursor is not changing size.
-	 */
-	scg_make_cell_visible (ic->scg, visible_col, visible_row, FALSE, TRUE);
-
-	/* FIXME FIXME FIXME
-	 * Ideally we would update the bounds BEFORE we scroll, this would
-	 * decrease the flicker.  Unfortunately, our optimization of clipping
-	 * the cursor to the currently visible region is getting in the way.
-	 * We are forced to make the region visible before we move the cursor.
-	 */
-	range_init (&r, corner->col, corner->row, end_col, end_row);
-	if (scg_special_cursor_bound_set (ic->scg, &r))
-		foo_canvas_update_now (FOO_CANVAS (gcanvas));
-}
-
 void
 item_cursor_set_visibility (ItemCursor *ic, gboolean visible)
 {
@@ -1126,42 +1086,43 @@ item_cursor_tip_setlabel (ItemCursor *ic, char const *text)
 }
 
 static gboolean
-cb_move_cursor (GnmCanvas *gcanvas, GnmCanvasSlideInfo const *info)
+cb_move_cursor (GnmPane *pane, GnmPaneSlideInfo const *info)
 {
 	ItemCursor *ic = info->user_data;
 	int const w = (ic->pos.end.col - ic->pos.start.col);
 	int const h = (ic->pos.end.row - ic->pos.start.row);
-	GnmCellPos corner;
+	GnmRange r;
 
-	corner.col = info->col - ic->col_delta;
-	if (corner.col < 0)
-		corner.col = 0;
-	else if (corner.col >= (SHEET_MAX_COLS - w))
-		corner.col = SHEET_MAX_COLS - w - 1;
+	r.start.col = info->col - ic->col_delta;
+	if (r.start.col < 0)
+		r.start.col = 0;
+	else if (r.start.col >= (SHEET_MAX_COLS - w))
+		r.start.col = SHEET_MAX_COLS - w - 1;
 
-	corner.row = info->row - ic->row_delta;
-	if (corner.row < 0)
-		corner.row = 0;
-	else if (corner.row >= (SHEET_MAX_ROWS - h))
-		corner.row = SHEET_MAX_ROWS - h - 1;
+	r.start.row = info->row - ic->row_delta;
+	if (r.start.row < 0)
+		r.start.row = 0;
+	else if (r.start.row >= (SHEET_MAX_ROWS - h))
+		r.start.row = SHEET_MAX_ROWS - h - 1;
 
 	item_cursor_tip_setlabel (ic, range_as_string (&ic->pos));
 
-	/* Make target cell visible, and adjust the cursor size */
-	item_cursor_set_bounds_visibly (ic, info->col, info->row, &corner,
-		corner.col + w, corner.row + h);
+	r.end.col = r.start.col + w;
+	r.end.row = r.start.row + h;
+	scg_special_cursor_bound_set (ic->scg, &r);
+	scg_make_cell_visible (ic->scg, info->col, info->row, FALSE, TRUE);
 	return FALSE;
 }
 
 static void
 item_cursor_handle_motion (ItemCursor *ic, GdkEvent *event,
-			   GnmCanvasSlideHandler slide_handler)
+			   GnmPaneSlideHandler slide_handler)
 {
 	FooCanvas *canvas = FOO_CANVAS_ITEM (ic)->canvas;
 
-	gnm_canvas_handle_motion (GNM_CANVAS (canvas),
+	gnm_pane_handle_motion (GNM_PANE (canvas),
 		canvas, &event->motion,
-		GNM_CANVAS_SLIDE_X | GNM_CANVAS_SLIDE_Y | GNM_CANVAS_SLIDE_AT_COLROW_BOUND,
+		GNM_PANE_SLIDE_X | GNM_PANE_SLIDE_Y | GNM_PANE_SLIDE_AT_COLROW_BOUND,
 		slide_handler, ic);
 }
 
@@ -1174,7 +1135,7 @@ item_cursor_drag_event (FooCanvasItem *item, GdkEvent *event)
 	case GDK_BUTTON_RELEASE:
 		/* Note : see comment below, and bug 30507 */
 		if ((int)event->button.button == ic->drag_button) {
-			gnm_canvas_slide_stop (GNM_CANVAS (item->canvas));
+			gnm_pane_slide_stop (GNM_PANE (item->canvas));
 			gnm_simple_canvas_ungrab (item, event->button.time);
 			item_cursor_do_drop (ic, (GdkEventButton *) event);
 		}
@@ -1198,7 +1159,7 @@ item_cursor_drag_event (FooCanvasItem *item, GdkEvent *event)
 }
 
 static gboolean
-cb_autofill_scroll (GnmCanvas *gcanvas, GnmCanvasSlideInfo const *info)
+cb_autofill_scroll (GnmPane *pane, GnmPaneSlideInfo const *info)
 {
 	ItemCursor *ic = info->user_data;
 	GnmRange r = ic->autofill_src;
@@ -1239,8 +1200,8 @@ cb_autofill_scroll (GnmCanvas *gcanvas, GnmCanvasSlideInfo const *info)
 	ic->last_tip_pos.col = col;
 	ic->last_tip_pos.row = row;
 
-	item_cursor_set_bounds_visibly (ic, col, row,
-		&r.start, r.end.col, r.end.row);
+	scg_special_cursor_bound_set (ic->scg, &r);
+	scg_make_cell_visible (ic->scg, col, row, FALSE, TRUE);
 
 	w = range_width (&ic->autofill_src);
 	h = range_height (&ic->autofill_src);
@@ -1293,7 +1254,7 @@ item_cursor_autofill_event (FooCanvasItem *item, GdkEvent *event)
 		gboolean default_increment =
 			ic->drag_button_state & GDK_CONTROL_MASK;
 
-		gnm_canvas_slide_stop (GNM_CANVAS (item->canvas));
+		gnm_pane_slide_stop (GNM_PANE (item->canvas));
 		gnm_simple_canvas_ungrab (item, event->button.time);
 
 		cmd_autofill (scg_wbc (scg), scg_sheet (scg), default_increment,
