@@ -14,17 +14,15 @@
 #include "gnumeric.h"
 #include "item-grid.h"
 
-#include "gnumeric-canvas.h"
-#include "workbook-edit.h"
+#include "gnm-pane-impl.h"
+#include "wbc-gtk-impl.h"
 #include "workbook-view.h"
-#include "workbook-control-gui-priv.h"
 #include "sheet-control-gui-priv.h"
 #include "sheet.h"
 #include "sheet-view.h"
 #include "sheet-style.h"
 #include "sheet-merge.h"
 #include "sheet-object-impl.h"
-#include "gnumeric-pane.h"
 #include "cell.h"
 #include "cell-draw.h"
 #include "cellspan.h"
@@ -135,21 +133,21 @@ cb_cursor_motion (ItemGrid *ig)
 {
 	Sheet const *sheet = scg_sheet (ig->scg);
 	FooCanvas *canvas = ig->canvas_item.canvas;
-	GnmCanvas *gcanvas = GNM_CANVAS (canvas);
+	GnmPane *pane = GNM_PANE (canvas);
 	int x, y;
 	GdkCursor *cursor;
 	GnmCellPos pos;
 	GnmHLink *old_link;
 
 	foo_canvas_w2c (canvas, ig->last_x, ig->last_y, &x, &y);
-	pos.col = gnm_canvas_find_col (gcanvas, x, NULL);
-	pos.row = gnm_canvas_find_row (gcanvas, y, NULL);
+	pos.col = gnm_pane_find_col (pane, x, NULL);
+	pos.row = gnm_pane_find_row (pane, y, NULL);
 
 	old_link = ig->cur_link;
 	ig->cur_link = sheet_hlink_find (sheet, &pos);
 	cursor = (ig->cur_link != NULL) ? ig->cursor_link : ig->cursor_cross;
-	if (gcanvas->pane->mouse_cursor != cursor) {
-		gnm_pane_mouse_cursor_set (gcanvas->pane, cursor);
+	if (pane->mouse_cursor != cursor) {
+		gnm_pane_mouse_cursor_set (pane, cursor);
 		scg_set_display_cursor (ig->scg);
 	}
 
@@ -250,6 +248,7 @@ item_grid_draw_merged_range (GdkDrawable *drawable, ItemGrid *ig,
 		 sv->edit_pos.row != range->start.row) &&
 		sv_is_full_range_selected (sv, range);
 
+	/* Get the coordinates of the visible region */
 	l = r = start_x;
 	if (view->start.col < range->start.col)
 		l += dir * scg_colrow_distance_get (ig->scg, TRUE,
@@ -279,15 +278,17 @@ item_grid_draw_merged_range (GdkDrawable *drawable, ItemGrid *ig,
 
 	/* Check for background THEN selection */
 	if (gnumeric_background_set_gc (style, gc,
-			ig->canvas_item.canvas, is_selected) ||
+		ig->canvas_item.canvas, is_selected) ||
 	    is_selected) {
 		/* Remember X excludes the far pixels */
-		if (sheet->text_is_rtl)
-			gdk_draw_rectangle (drawable, gc, TRUE, r, t, l-r+1, b-t+1);
-		else
+		if (dir > 0)
 			gdk_draw_rectangle (drawable, gc, TRUE, l, t, r-l+1, b-t+1);
+		else
+			gdk_draw_rectangle (drawable, gc, TRUE, r, t, l-r+1, b-t+1);
 	}
 
+	/* Expand the coords to include non-visible areas too.  The clipped
+	 * region is only necessary when drawing the background */
 	if (range->start.col < view->start.col)
 		l -= dir * scg_colrow_distance_get (ig->scg, TRUE,
 			range->start.col, view->start.col);
@@ -307,14 +308,17 @@ item_grid_draw_merged_range (GdkDrawable *drawable, ItemGrid *ig,
 		if (ri->needs_respan)
 			row_calc_spans ((ColRowInfo *)ri, cell->pos.row, sheet);
 
-		if (sheet->text_is_rtl)
-			cell_draw (cell, ig->gc.cell, drawable,
-				r, t, l - r, b - t, -1);
-		else
+		if (dir > 0)
 			cell_draw (cell, ig->gc.cell, drawable,
 				l, t, r - l, b - t, -1);
+		else
+			cell_draw (cell, ig->gc.cell, drawable,
+				r, t, l - r, b - t, -1);
 	}
-	gnm_style_border_draw_diag (style, drawable, l, t, r, b);
+	if (dir > 0)
+		gnm_style_border_draw_diag (style, drawable, l, t, r, b);
+	else
+		gnm_style_border_draw_diag (style, drawable, r, t, l, b);
 }
 
 static void
@@ -357,10 +361,10 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 	gint width  = expose->area.width;
 	gint height = expose->area.height;
 	FooCanvas *canvas = item->canvas;
-	GnmCanvas *gcanvas = GNM_CANVAS (canvas);
-	Sheet const *sheet = scg_sheet (gcanvas->simple.scg);
-	WorkbookControlGUI *wbcg = scg_wbcg (gcanvas->simple.scg);
-	GnmCell const * const edit_cell = wbcg->wb_control.editing_cell;
+	GnmPane *pane = GNM_PANE (canvas);
+	Sheet const *sheet = scg_sheet (pane->simple.scg);
+	WBCGtk *wbcg = scg_wbcg (pane->simple.scg);
+	GnmCell const * const edit_cell = wbcg->editing_cell;
 	ItemGrid *ig = ITEM_GRID (item);
 	ColRowInfo const *ri = NULL, *next_ri = NULL;
 	int const dir = sheet->text_is_rtl ? -1 : 1;
@@ -373,8 +377,8 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 	 * However, that feels like more hassle that it is worth.  Look into this someday.
 	 */
 	int x, y, col, row, n, start_col, end_col, start_x, offset;
-	int start_row = gnm_canvas_find_row (gcanvas, expose->area.y-2, &y);
-	int end_row = gnm_canvas_find_row (gcanvas, expose->area.y+height+2, NULL);
+	int start_row = gnm_pane_find_row (pane, expose->area.y-2, &y);
+	int end_row = gnm_pane_find_row (pane, expose->area.y+height+2, NULL);
 	int const start_y = y;
 
 	GnmStyleRow sr, next_sr;
@@ -394,18 +398,20 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 		ig->scg->new_object == NULL;
 
 	if (dir < 0) {
-		start_col = gnm_canvas_find_col (gcanvas, expose->area.x+width+2, &start_x);
-		end_col   = gnm_canvas_find_col (gcanvas, expose->area.x-2, NULL);
+		start_col = gnm_pane_find_col (pane, expose->area.x+width+2, &start_x);
+		end_col   = gnm_pane_find_col (pane, expose->area.x-2, NULL);
 	} else {
-		start_col = gnm_canvas_find_col (gcanvas, expose->area.x-2, &start_x);
-		end_col   = gnm_canvas_find_col (gcanvas, expose->area.x+width+2, NULL);
+		start_col = gnm_pane_find_col (pane, expose->area.x-2, &start_x);
+		end_col   = gnm_pane_find_col (pane, expose->area.x+width+2, NULL);
 	}
 
 	g_return_if_fail (start_col <= end_col);
 
 #if 0
-	g_printerr ("%s%s:", col_name(start_col), row_name(start_row));
-	g_printerr ("%s%s <= %d vs %d\n", col_name(end_col), row_name(end_row), y, expose->area.y);
+	g_printerr ("%s:", cell_coord_name (start_col, start_row));
+	g_printerr ("%s <= %d vs %d", cell_coord_name(end_col, end_row), y, expose->area.y);
+	g_printerr (" [%s]\n", cell_coord_name (ig->bound.end.col, ig->bound.end.row));
+	
 #endif
 
 	/* clip to bounds */
@@ -431,6 +437,13 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 	    end_row < ig->bound.start.row || start_row > ig->bound.end.row)
 		return;
 
+	/* Respan all rows that need it.  */
+	for (row = start_row; row <= end_row; row++) {
+		ColRowInfo const *ri = sheet_row_get_info (sheet, row);
+		if (ri->visible && ri->needs_respan)
+			row_calc_spans ((ColRowInfo *)ri, row, sheet);
+	}
+
 	sheet_style_update_grid_color (sheet);
 
 	/* Fill entire region with default background (even past far edge) */
@@ -497,12 +510,6 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 			}
 		}
 
-		/* it is safe to const_cast because only the a non-default row
-		 * will ever get flagged.
-		 */
-		if (ri->needs_respan)
-			row_calc_spans ((ColRowInfo *)ri, row, sheet);
-
 		/* look for merges that start on this row, on the first painted row
 		 * also check for merges that start above. */
 		view.start.row = row;
@@ -589,8 +596,8 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 							clear_bottom = TRUE;
 					}
 
-					x += scg_colrow_distance_get (
-						gcanvas->simple.scg, TRUE, col, last+1);
+					x += dir * scg_colrow_distance_get (
+						pane->simple.scg, TRUE, col, last+1);
 					col = last;
 
 					if (first < start_col) {
@@ -667,12 +674,12 @@ plain_draw : /* a quick hack to deal with 142267 */
 				 * justify or center justify) compute the pixel difference */
 				if (start_span_col != cell->pos.col)
 					center_offset += scg_colrow_distance_get (
-						gcanvas->simple.scg, TRUE,
+						pane->simple.scg, TRUE,
 						start_span_col, cell->pos.col);
 
 				if (start_span_col != col) {
 					offset = scg_colrow_distance_get (
-						gcanvas->simple.scg, TRUE,
+						pane->simple.scg, TRUE,
 						start_span_col, col);
 					tmp_width += offset;
 					if (dir > 0)
@@ -681,7 +688,7 @@ plain_draw : /* a quick hack to deal with 142267 */
 				}
 				if (end_span_col != col) {
 					offset = scg_colrow_distance_get (
-						gcanvas->simple.scg, TRUE,
+						pane->simple.scg, TRUE,
 						col+1, end_span_col + 1);
 					tmp_width += offset;
 					if (dir < 0)
@@ -695,7 +702,7 @@ plain_draw : /* a quick hack to deal with 142267 */
 				sr.vertical [col] = NULL;
 
 			if (dir > 0)
-			x += ci->size_pixels;
+				x += ci->size_pixels;
 		}
 		gnm_style_borders_row_draw (prev_vert, &sr,
 					drawable, start_x, y, y+ri->size_pixels,
@@ -729,13 +736,13 @@ plain_draw : /* a quick hack to deal with 142267 */
 
 	if (row >= ig->bound.end.row) {
 		gnm_style_borders_row_draw (prev_vert, &sr,
-					drawable, start_x, y, y, colwidths, FALSE, dir);
-		if (gcanvas->pane->index >= 2)
+			drawable, start_x, y, y, colwidths, FALSE, dir);
+		if (pane->index >= 2)
 			gdk_draw_line (drawable, ig->gc.bound, start_x, y, x, y);
 	}
 	if (col >= ig->bound.end.col &&
 	    /* TODO : Add pane flags to avoid hard coding pane numbers */
-	    (gcanvas->pane->index == 1 || gcanvas->pane->index == 2))
+	    (pane->index == 1 || pane->index == 2))
 		gdk_draw_line (drawable, ig->gc.bound, x, start_y, x, y);
 
 	g_slist_free (merged_used);	   /* merges with bottom in view */
@@ -757,7 +764,7 @@ item_grid_point (FooCanvasItem *item, double x, double y, int cx, int cy,
 static gboolean
 ig_obj_create_begin (ItemGrid *ig, GdkEventButton *event)
 {
-	GnmCanvas *gcanvas = GNM_CANVAS (FOO_CANVAS_ITEM (ig)->canvas);
+	GnmPane *pane = GNM_PANE (FOO_CANVAS_ITEM (ig)->canvas);
 	SheetObject *so = ig->scg->new_object;
 	SheetObjectAnchor anchor;
 	double coords[4];
@@ -767,12 +774,12 @@ ig_obj_create_begin (ItemGrid *ig, GdkEventButton *event)
 
 	coords[0] = coords[2] = event->x;
 	coords[1] = coords[3] = event->y;
-	sheet_object_anchor_init (&anchor, NULL, NULL, NULL, GOD_ANCHOR_DIR_DOWN_RIGHT);
+	sheet_object_anchor_init (&anchor, NULL, NULL, GOD_ANCHOR_DIR_DOWN_RIGHT);
 	scg_object_coords_to_anchor (ig->scg, coords, &anchor);
 	sheet_object_set_anchor (so, &anchor);
 	sheet_object_set_sheet (so, scg_sheet (ig->scg));
 	scg_object_select (ig->scg, so);
-	gnm_pane_object_start_resize (gcanvas->pane, event, so, 7, TRUE);
+	gnm_pane_object_start_resize (pane, event, so, 7, TRUE);
 
 	return TRUE;
 }
@@ -784,21 +791,22 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 {
 	FooCanvasItem *item = FOO_CANVAS_ITEM (ig);
 	FooCanvas    *canvas = item->canvas;
-	GnmCanvas *gcanvas = GNM_CANVAS (canvas);
+	GnmPane *pane = GNM_PANE (canvas);
 	SheetControlGUI *scg = ig->scg;
-	WorkbookControlGUI *wbcg = scg_wbcg (scg);
-	SheetControl *sc = (SheetControl *)scg;
-	Sheet *sheet = scg_sheet (scg);
+	WBCGtk *wbcg = scg_wbcg (scg);
+	SheetControl	*sc = (SheetControl *)scg;
+	SheetView	*sv = sc_view (sc);
+	Sheet		*sheet = sv_sheet (sv);
 	GnmCellPos	pos;
 	int x, y;
 	gboolean edit_showed_dialog;
 	gboolean already_selected;
 
-	gnm_canvas_slide_stop (gcanvas);
+	gnm_pane_slide_stop (pane);
 
 	foo_canvas_w2c (canvas, event->x, event->y, &x, &y);
-	pos.col = gnm_canvas_find_col (gcanvas, x, NULL);
-	pos.row = gnm_canvas_find_row (gcanvas, y, NULL);
+	pos.col = gnm_pane_find_col (pane, x, NULL);
+	pos.row = gnm_pane_find_row (pane, y, NULL);
 
 	/* GnmRange check first */
 	if (pos.col >= SHEET_MAX_COLS)
@@ -826,7 +834,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 			scg_rangesel_extend_to (scg, pos.col, pos.row);
 		else
 			scg_rangesel_bound (scg, pos.col, pos.row, pos.col, pos.row);
-		gnm_canvas_slide_init (gcanvas);
+		gnm_pane_slide_init (pane);
 		gnm_simple_canvas_grab (item,
 			GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
 			NULL, event->time);
@@ -839,7 +847,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	if (event->button == 1 && wbcg_rangesel_possible (wbcg)) {
 		scg_rangesel_start (scg, pos.col, pos.row, pos.col, pos.row);
 		ig->selecting = ITEM_GRID_SELECTING_FORMULA_RANGE;
-		gnm_canvas_slide_init (gcanvas);
+		gnm_pane_slide_init (pane);
 		gnm_simple_canvas_grab (item,
 			GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
 			NULL, event->time);
@@ -855,12 +863,13 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	if (!wbcg_edit_finish (wbcg, WBC_EDIT_ACCEPT, &edit_showed_dialog))
 		return TRUE;
 
+	if (event->button == 1 && !sheet_selection_is_allowed (sheet, &pos))
+		return TRUE;
+
 	/* button 1 will always change the selection,  the other buttons will
-	 * only effect things if the target is not already selected.
-	 */
-	already_selected = sv_is_pos_selected (sc_view (sc), pos.col, pos.row);
+	 * only effect things if the target is not already selected.  */
+	already_selected = sv_is_pos_selected (sv, pos.col, pos.row);
 	if (event->button == 1 || !already_selected) {
-		SheetView *sv = sc_view (sc);
 		if (!(event->state & (GDK_CONTROL_MASK|GDK_SHIFT_MASK)))
 			sv_selection_reset (sv);
 
@@ -897,7 +906,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 
 		ig->last_click_time = event->time;
 		ig->selecting = ITEM_GRID_SELECTING_CELL_RANGE;
-		gnm_canvas_slide_init (gcanvas);
+		gnm_pane_slide_init (pane);
 		gnm_simple_canvas_grab (item,
 			GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
 			NULL, event->time);
@@ -920,17 +929,17 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
  */
 
 static gboolean
-cb_extend_cell_range (GnmCanvas *gcanvas, GnmCanvasSlideInfo const *info)
+cb_extend_cell_range (GnmPane *pane, GnmPaneSlideInfo const *info)
 {
-	sv_selection_extend_to (scg_view (gcanvas->simple.scg),
+	sv_selection_extend_to (scg_view (pane->simple.scg),
 				info->col, info->row);
 	return TRUE;
 }
 
 static gboolean
-cb_extend_expr_range (GnmCanvas *gcanvas, GnmCanvasSlideInfo const *info)
+cb_extend_expr_range (GnmPane *pane, GnmPaneSlideInfo const *info)
 {
-	scg_rangesel_extend_to (gcanvas->simple.scg, info->col, info->row);
+	scg_rangesel_extend_to (pane->simple.scg, info->col, info->row);
 	return TRUE;
 }
 
@@ -939,7 +948,7 @@ cb_cursor_come_to_rest (ItemGrid *ig)
 {
 	Sheet const *sheet = scg_sheet (ig->scg);
 	FooCanvas *canvas = ig->canvas_item.canvas;
-	GnmCanvas *gcanvas = GNM_CANVAS (canvas);
+	GnmPane *pane = GNM_PANE (canvas);
 	GnmHLink *link;
 	int x, y;
 	GnmCellPos pos;
@@ -948,8 +957,8 @@ cb_cursor_come_to_rest (ItemGrid *ig)
 	/* Be anal and look it up in case something has destroyed the link
 	 * since the last motion */
 	foo_canvas_w2c (canvas, ig->last_x, ig->last_y, &x, &y);
-	pos.col = gnm_canvas_find_col (gcanvas, x, NULL);
-	pos.row = gnm_canvas_find_row (gcanvas, y, NULL);
+	pos.col = gnm_pane_find_col (pane, x, NULL);
+	pos.row = gnm_pane_find_row (pane, y, NULL);
 
 	link = sheet_hlink_find (sheet, &pos);
 	if (link != NULL && (tiptext = gnm_hlink_get_tip (link)) != NULL) {
@@ -970,8 +979,8 @@ static gint
 item_grid_event (FooCanvasItem *item, GdkEvent *event)
 {
 	FooCanvas *canvas = item->canvas;
-	GnmCanvas *gcanvas = GNM_CANVAS (canvas);
-	ItemGrid *ig = ITEM_GRID (item);
+	GnmPane   *pane = GNM_PANE (canvas);
+	ItemGrid  *ig = ITEM_GRID (item);
 	SheetControlGUI *scg = ig->scg;
 	Sheet *sheet = scg_sheet (scg);
 
@@ -993,7 +1002,7 @@ item_grid_event (FooCanvasItem *item, GdkEvent *event)
 		if (event->button.button != 1)
 			return FALSE;
 
-		gnm_canvas_slide_stop (gcanvas);
+		gnm_pane_slide_stop (pane);
 
 		switch (selecting) {
 		case ITEM_GRID_NO_SELECTION:
@@ -1035,7 +1044,7 @@ item_grid_event (FooCanvasItem *item, GdkEvent *event)
 	}
 
 	case GDK_MOTION_NOTIFY: {
-		GnmCanvasSlideHandler slide_handler = NULL;
+		GnmPaneSlideHandler slide_handler = NULL;
 		switch (ig->selecting) {
 		case ITEM_GRID_NO_SELECTION:
 			if (ig->cursor_timer == 0)
@@ -1058,9 +1067,9 @@ item_grid_event (FooCanvasItem *item, GdkEvent *event)
 			g_assert_not_reached ();
 		}
 
-		gnm_canvas_handle_motion (gcanvas, canvas, &event->motion,
-			GNM_CANVAS_SLIDE_X | GNM_CANVAS_SLIDE_Y |
-			GNM_CANVAS_SLIDE_AT_COLROW_BOUND,
+		gnm_pane_handle_motion (pane, canvas, &event->motion,
+			GNM_PANE_SLIDE_X | GNM_PANE_SLIDE_Y |
+			GNM_PANE_SLIDE_AT_COLROW_BOUND,
 			slide_handler, NULL);
 		return TRUE;
 	}
