@@ -8,14 +8,14 @@ extern int	 dependency_debugging;
 extern int	 expression_sharing_debugging;
 extern int	 print_debugging;
 extern gboolean	 initial_workbook_open_complete;
-extern gboolean  gnumeric_no_splash;
-extern gboolean  gnumeric_no_warnings;
 extern char	*x_geometry;
 
-void gnm_pre_parse_init (char const* gnumeric_binary);
-void gnm_common_init	(gboolean fast);
-int  gnm_dump_func_defs (char const* filename,
-			 int dump_type); /* changes as needed */
-void gnm_shutdown	(void);
+char const **gnm_pre_parse_init     (int argc, gchar const **argv);
+void	     gnm_pre_parse_shutdown (void);
+void	     gnm_init		    (gboolean fast);
+void	     gnm_shutdown	    (void);
+
+/* Internal */
+int gnm_dump_func_defs (char const* filename, int dump_type); /* changes as needed */
 
 #endif /* GNUMERIC_LIBGNUMERIC_H */
