@@ -218,7 +218,7 @@ gnm_component_factory (BonoboGenericFactory *this,
 
 	d (printf ("%s producing a '%s'\n", "gnm_component_factory", oaf_iid));
 	wbc = workbook_control_component_new ();
-	w = WORKBOOK_CONTROL_GUI (wbc)->table;
+	w = WBC_GTK (wbc)->table;
 	g_object_set_data (G_OBJECT (w), WBC_KEY, wbc);
 	gtk_widget_show(w);
 	control = bonobo_control_new (w);
@@ -245,11 +245,11 @@ gnm_component_factory (BonoboGenericFactory *this,
 int
 main (int argc, char *argv [])
 {
-	gnm_pre_parse_init (argv[0]);
+	argv = gnm_pre_parse_init (argc, argv);
 
 	BONOBO_FACTORY_INIT ("gnumeric-component", VERSION, &argc, argv);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	gnm_common_init (TRUE);
+	gnm_init (TRUE);
 
 	return bonobo_generic_factory_main ("OAFIID:GNOME_Gnumeric_Factory",
 					    gnm_component_factory, NULL);
