@@ -2,12 +2,11 @@
 #define GNUMERIC_PRINT_H
 
 #include "gnumeric.h"
-#include "workbook-control-gui.h"
 #include <gsf/gsf-output.h>
 
-#define GNUMERIC_PRINT_SETTING_PRINTRANGE_KEY "GnumericPrintRange"
-#define GNUMERIC_PRINT_SETTING_PRINT_FROM_SHEET_KEY "GnumericPrintFromSheet"
-#define GNUMERIC_PRINT_SETTING_PRINT_TO_SHEET_KEY "GnumericPrintToSheet"
+#define GNUMERIC_PRINT_SETTING_PRINTRANGE_KEY		"GnumericPrintRange"
+#define GNUMERIC_PRINT_SETTING_PRINT_FROM_SHEET_KEY	"GnumericPrintFromSheet"
+#define GNUMERIC_PRINT_SETTING_PRINT_TO_SHEET_KEY	"GnumericPrintToSheet"
 
 typedef enum {
 	PRINT_ACTIVE_SHEET,
@@ -18,7 +17,7 @@ typedef enum {
 	PRINT_SHEET_SELECTION_IGNORE_PRINTAREA
 } PrintRange;
 
-void gnm_print_sheet (WorkbookControlGUI *wbcg, Sheet *sheet,
+void gnm_print_sheet (WorkbookControl *wbc, Sheet *sheet,
 		      gboolean preview, PrintRange default_range,
 		      GsfOutput *export_dst);
 
