@@ -6,7 +6,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "search.h"
 
@@ -76,10 +76,10 @@ gnm_search_replace_verify (GnmSearchReplace *sr, gboolean repl)
 /* ------------------------------------------------------------------------- */
 
 static int
-cb_order_sheet_row_col (const void *_a, const void *_b)
+cb_order_sheet_row_col (void const *_a, void const *_b)
 {
-	const GnmEvalPos *a = *(const GnmEvalPos **)_a;
-	const GnmEvalPos *b = *(const GnmEvalPos **)_b;
+	GnmEvalPos const *a = *(GnmEvalPos const **)_a;
+	GnmEvalPos const *b = *(GnmEvalPos const **)_b;
 	int i;
 
 	i = strcmp (a->sheet->name_unquoted_collate_key,
@@ -95,10 +95,10 @@ cb_order_sheet_row_col (const void *_a, const void *_b)
 }
 
 static int
-cb_order_sheet_col_row (const void *_a, const void *_b)
+cb_order_sheet_col_row (void const *_a, void const *_b)
 {
-	const GnmEvalPos *a = *(const GnmEvalPos **)_a;
-	const GnmEvalPos *b = *(const GnmEvalPos **)_b;
+	GnmEvalPos const *a = *(GnmEvalPos const **)_a;
+	GnmEvalPos const *b = *(GnmEvalPos const **)_b;
 	int i;
 
 	i = strcmp (a->sheet->name_unquoted_collate_key,
@@ -114,24 +114,19 @@ cb_order_sheet_col_row (const void *_a, const void *_b)
 }
 
 static GnmValue *
-search_collect_cells_cb (Sheet *sheet, int col, int row,
-			 GnmCell *cell, GPtrArray *cells)
+search_collect_cells_cb (GnmCellIter const *iter, gpointer user)
 {
+	GPtrArray *cells = user;
 	GnmEvalPos *ep = g_new (GnmEvalPos, 1);
 
-	ep->sheet = sheet;
-	ep->eval.col = col;
-	ep->eval.row = row;
-
-	g_ptr_array_add (cells, ep);
+	g_ptr_array_add (cells, eval_pos_init_cell (ep, iter->cell));
 
 	return NULL;
-
 }
 
 /* Collect a list of all cells subject to search.  */
 GPtrArray *
-search_collect_cells (GnmSearchReplace *sr)
+gnm_search_collect_cells (GnmSearchReplace *sr)
 {
 	GPtrArray *cells;
 
@@ -142,9 +137,7 @@ search_collect_cells (GnmSearchReplace *sr)
 		break;
 
 	case GNM_SRS_SHEET:
-		cells = sheet_cells (sr->sheet,
-				     0, 0, SHEET_MAX_COLS, SHEET_MAX_ROWS,
-				     TRUE);
+		cells = sheet_cells (sr->sheet, TRUE);
 		break;
 
 	case GNM_SRS_RANGE:
@@ -156,7 +149,7 @@ search_collect_cells (GnmSearchReplace *sr)
 		global_range_list_foreach (range_list,
 			   eval_pos_init_sheet (&ep, sr->sheet),
 			   CELL_ITER_IGNORE_BLANK,
-			   (CellIterFunc) &search_collect_cells_cb, cells);
+			   search_collect_cells_cb, cells);
 		range_list_destroy (range_list);
 		break;
 	}
@@ -176,7 +169,7 @@ search_collect_cells (GnmSearchReplace *sr)
 }
 
 void
-search_collect_cells_free (GPtrArray *cells)
+gnm_search_collect_cells_free (GPtrArray *cells)
 {
 	unsigned i;
 
@@ -188,44 +181,44 @@ search_collect_cells_free (GPtrArray *cells)
 /* ------------------------------------------------------------------------- */
 /*
  * sr: The search spec.
- * cells: An array of GnmEvalPos*, presumably a result of search_collect_cells.
+ * cells: An array of GnmEvalPos*, presumably a result of gnm_search_collect_cells.
  *
- * Returns an array of SearchFilterResult*s, which the caller must free.
+ * Returns an array of GnmSearchFilterResult*s, which the caller must free.
  */
 
 GPtrArray *
-search_filter_matching (GnmSearchReplace *sr, const GPtrArray *cells)
+gnm_search_filter_matching (GnmSearchReplace *sr, const GPtrArray *cells)
 {
 	unsigned i;
 	GPtrArray *result = g_ptr_array_new ();
 
 	for (i = 0; i < cells->len; i++) {
-		SearchReplaceCellResult cell_res;
-		SearchReplaceValueResult value_res;
-		SearchReplaceCommentResult comment_res;
+		GnmSearchReplaceCellResult cell_res;
+		GnmSearchReplaceValueResult value_res;
+		GnmSearchReplaceCommentResult comment_res;
 		gboolean found;
 		const GnmEvalPos *ep = g_ptr_array_index (cells, i);
 
 		found = gnm_search_replace_cell (sr, ep, FALSE, &cell_res);
 		g_free (cell_res.old_text);
 		if (found) {
-			SearchFilterResult *item = g_new (SearchFilterResult, 1);
+			GnmSearchFilterResult *item = g_new (GnmSearchFilterResult, 1);
 			item->ep = *ep;
-			item->locus = SRL_contents;
+			item->locus = GNM_SRL_CONTENTS;
 			g_ptr_array_add (result, item);
 		}
 
 		if (gnm_search_replace_value (sr, ep, &value_res)) {
-			SearchFilterResult *item = g_new (SearchFilterResult, 1);
+			GnmSearchFilterResult *item = g_new (GnmSearchFilterResult, 1);
 			item->ep = *ep;
-			item->locus = SRL_value;
+			item->locus = GNM_SRL_VALUE;
 			g_ptr_array_add (result, item);
 		}
 
 		if (gnm_search_replace_comment (sr, ep, FALSE, &comment_res)) {
-			SearchFilterResult *item = g_new (SearchFilterResult, 1);
+			GnmSearchFilterResult *item = g_new (GnmSearchFilterResult, 1);
 			item->ep = *ep;
-			item->locus = SRL_commment;
+			item->locus = GNM_SRL_COMMENT;
 			g_ptr_array_add (result, item);
 		}
 	}
@@ -234,7 +227,7 @@ search_filter_matching (GnmSearchReplace *sr, const GPtrArray *cells)
 }
 
 void
-search_filter_matching_free (GPtrArray *matches)
+gnm_search_filter_matching_free (GPtrArray *matches)
 {
 	unsigned i;
 	for (i = 0; i < matches->len; i++)
@@ -248,10 +241,13 @@ gboolean
 gnm_search_replace_comment (GnmSearchReplace *sr,
 			    const GnmEvalPos *ep,
 			    gboolean repl,
-			    SearchReplaceCommentResult *res)
+			    GnmSearchReplaceCommentResult *res)
 {
-	g_return_val_if_fail (res, FALSE);
+	gboolean found;
+	char *norm_text;
 
+	g_return_val_if_fail (res, FALSE);
+	
 	res->comment = NULL;
 	res->old_text = NULL;
 	res->new_text = NULL;
@@ -265,13 +261,19 @@ gnm_search_replace_comment (GnmSearchReplace *sr,
 
 	res->old_text = cell_comment_text_get (res->comment);
 
+	norm_text = g_utf8_normalize (res->old_text, -1, G_NORMALIZE_DEFAULT);
+
 	if (repl) {
 		res->new_text = go_search_replace_string (GO_SEARCH_REPLACE (sr),
-							  res->old_text);
-		return (res->new_text != NULL);
+							  norm_text);
+		found = (res->new_text != NULL);
 	} else
-		return go_search_match_string (GO_SEARCH_REPLACE (sr),
-					       res->old_text);
+		found = go_search_match_string (GO_SEARCH_REPLACE (sr),
+						norm_text);
+
+	g_free (norm_text);
+
+	return found;
 }
 
 /* ------------------------------------------------------------------------- */
@@ -280,11 +282,12 @@ gboolean
 gnm_search_replace_cell (GnmSearchReplace *sr,
 			 const GnmEvalPos *ep,
 			 gboolean repl,
-			 SearchReplaceCellResult *res)
+			 GnmSearchReplaceCellResult *res)
 {
 	GnmCell *cell;
 	GnmValue *v;
 	gboolean is_expr, is_value, is_string, is_other;
+	gboolean found = FALSE;
 
 	g_return_val_if_fail (res, FALSE);
 
@@ -299,21 +302,22 @@ gnm_search_replace_cell (GnmSearchReplace *sr,
 
 	v = cell->value;
 
-	is_expr = cell_has_expr (cell);
-	is_value = !is_expr && !cell_is_empty (cell) && v;
+	is_expr = gnm_cell_has_expr (cell);
+	is_value = !is_expr && !gnm_cell_is_empty (cell) && v;
 	is_string = is_value && (VALUE_IS_STRING (v));
 	is_other = is_value && !is_string;
 
 	if ((is_expr && sr->search_expressions) ||
 	    (is_string && sr->search_strings) ||
 	    (is_other && sr->search_other_values)) {
-		const char *actual_src;
+		char *actual_src;
 		gboolean initial_quote;
 
-		res->old_text = cell_get_entered_text (cell);
+		res->old_text = gnm_cell_get_entered_text (cell);
 		initial_quote = (is_string && res->old_text[0] == '\'');
 
-		actual_src = res->old_text + (initial_quote ? 1 : 0);
+		actual_src = g_utf8_normalize (res->old_text + (initial_quote ? 1 : 0),
+					       -1, G_NORMALIZE_DEFAULT);
 
 		if (repl) {
 			res->new_text = go_search_replace_string (GO_SEARCH_REPLACE (sr),
@@ -330,13 +334,15 @@ gnm_search_replace_cell (GnmSearchReplace *sr,
 					g_free (res->new_text);
 					res->new_text = tmp;
 				}
-				return TRUE;
+				found = TRUE;
 			}
 		} else
-			return go_search_match_string (GO_SEARCH_REPLACE (sr), actual_src);
+			found = go_search_match_string (GO_SEARCH_REPLACE (sr), actual_src);
+
+		g_free (actual_src);
 	}
 
-	return FALSE;
+	return found;
 }
 
 /* ------------------------------------------------------------------------- */
@@ -344,7 +350,7 @@ gnm_search_replace_cell (GnmSearchReplace *sr,
 gboolean
 gnm_search_replace_value (GnmSearchReplace *sr,
 			  const GnmEvalPos *ep,
-			  SearchReplaceValueResult *res)
+			  GnmSearchReplaceValueResult *res)
 {
 	GnmCell *cell;
 
@@ -358,10 +364,10 @@ gnm_search_replace_value (GnmSearchReplace *sr,
 		return FALSE;
 
 	cell = res->cell = sheet_cell_get (ep->sheet, ep->eval.col, ep->eval.row);
-	if (!cell || !cell_has_expr (cell) || !cell->value)
+	if (!cell || !gnm_cell_has_expr (cell) || !cell->value)
 		return FALSE;
 	else {
-		char *val = value_get_as_string (cell->value);
+		char *val = g_utf8_normalize (value_peek_string (cell->value), -1, G_NORMALIZE_DEFAULT);
 		gboolean res = go_search_match_string (GO_SEARCH_REPLACE (sr), val);
 		g_free (val);
 		return res;
@@ -456,7 +462,7 @@ gnm_search_replace_set_sheet (GnmSearchReplace *sr, Sheet *sheet)
 }
 
 static void
-gnm_search_replace_set_range_text (GnmSearchReplace *sr, const char *text)
+gnm_search_replace_set_range_text (GnmSearchReplace *sr, char const *text)
 {
 	char *text_copy = g_strdup (text);
 	g_free (sr->range_text);
