@@ -182,9 +182,11 @@ afa_teach_cell (AutoFiller *af, const GnmCell *cell, int n)
 		af->status = AFS_READY;
 		break;
 	default: {
-		gnm_float step2 = f - (afa->base + n * afa->step);
-		gnm_float err = (afa->step - step2) /
-			(gnm_abs (afa->step) + gnm_abs (step2));
+		gnm_float step2 = (f - afa->base) / n;
+		gnm_float step_sum = gnm_abs (afa->step) + gnm_abs (step2);
+		gnm_float err = step_sum
+			? gnm_abs (afa->step - step2) / step_sum
+			: 0;
 		/* Be fairly lenient: */
 		if (err > (n + 64) * GNM_EPSILON) {
 			af->status = AFS_ERROR;
@@ -545,7 +547,7 @@ afm_teach_cell (AutoFiller *af, const GnmCell *cell, int n)
 	}
 
 	sf = gnm_cell_get_format (cell);
-	if (VALUE_IS_NUMBER (value) && sf->family != GO_FORMAT_DATE)
+	if (gnm_format_is_date_for_value (sf, value) != 1)
 		goto bad;
 
 	afm->dateconv = workbook_date_conv (cell->base.sheet->workbook);
@@ -876,7 +878,7 @@ afc_set_cell_hint (AutoFiller *af, GnmCell *cell, GnmCellPos const *pos,
 					 gnm_expr_top_new (aexpr));
 			else {
 				res = gnm_expr_as_string (aexpr,
-					&rinfo.pos, gnm_expr_conventions_default);
+					&rinfo.pos, gnm_conventions_default);
 				gnm_expr_free (aexpr);
 			}
 		} else if (texpr) {
@@ -884,14 +886,14 @@ afc_set_cell_hint (AutoFiller *af, GnmCell *cell, GnmCellPos const *pos,
 				gnm_cell_set_expr (cell, texpr);
 			else
 				res = gnm_expr_top_as_string (texpr,
-					&rinfo.pos, gnm_expr_conventions_default);
+					&rinfo.pos, gnm_conventions_default);
 			gnm_expr_top_unref (texpr);
 		} else {
 			if (doit)
 				gnm_cell_set_expr (cell, src_texpr);
 			else
 				res = gnm_expr_top_as_string (src_texpr,
-					&rinfo.pos, gnm_expr_conventions_default);
+					&rinfo.pos, gnm_conventions_default);
 		}
 	} else if (src) {
 		if (doit)
