@@ -24,16 +24,15 @@
 #include "gnumeric.h"
 #include "sheet-object-graph.h"
 
+#include "gnm-pane-impl.h"
 #include "sheet-control-gui.h"
-#include "gnumeric-canvas.h"
-#include "gnumeric-pane.h"
 #include "str.h"
 #include "gui-util.h"
 #include "gui-file.h"
 #include "gnm-graph-window.h"
 #include "style-color.h"
 #include "sheet-object-impl.h"
-#include "workbook-edit.h"
+#include "wbc-gtk.h"
 #include "commands.h"
 #include "application.h"
 #include "xml-io.h"
@@ -54,10 +53,6 @@
 #include <goffice/app/go-cmd-context.h>
 #include <goffice/gtk/go-graph-widget.h>
 
-#ifdef WITH_GNOME_PRINT
-#include <goffice/graph/gog-renderer-gnome-print.h>
-#endif
-
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-output-stdio.h>
@@ -179,9 +174,9 @@ gnm_sog_finalize (GObject *obj)
 static SheetObjectView *
 gnm_sog_new_view (SheetObject *so, SheetObjectViewContainer *container)
 {
-	GnmCanvas *gcanvas = ((GnmPane *)container)->gcanvas;
+	GnmPane *pane = GNM_PANE (container);
 	SheetObjectGraph *sog = SHEET_OBJECT_GRAPH (so);
-	FooCanvasItem *view = foo_canvas_item_new (gcanvas->object_views,
+	FooCanvasItem *view = foo_canvas_item_new (pane->object_views,
 		so_graph_foo_view_get_type (),
 		"renderer",	sog->renderer,
 		NULL);
@@ -215,11 +210,9 @@ gnm_sog_get_target_list (SheetObject const *so)
 static GtkTargetList *
 gnm_sog_get_object_target_list (SheetObject const *so)
 {
-	GtkTargetList *tl, *tl2;
-	GtkTargetPair *pair;
-	tl = gtk_target_list_new (NULL, 0);
-	gtk_target_list_add (tl, gdk_atom_intern
-					("application/x-goffice-graph", FALSE), 0, 0);
+	GtkTargetList *tl = gtk_target_list_new (NULL, 0);
+	gtk_target_list_add (tl,
+		gdk_atom_intern ("application/x-goffice-graph", FALSE), 0, 0);
 	return tl;
 }
 
@@ -274,7 +267,7 @@ gnm_sog_write_object (SheetObject const *so, char const *format,
 static void
 sog_cb_save_as (SheetObject *so, SheetControl *sc)
 {
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	char *uri;
 	GError *err = NULL;
 	GsfOutput *output;
@@ -391,23 +384,13 @@ gnm_sog_copy (SheetObject *dst, SheetObject const *src)
 	g_object_unref (graph);
 }
 
-#ifdef WITH_GNOME_PRINT
-static void
-gnm_sog_print (SheetObject const *so, GnomePrintContext *ctx,
-			  double width, double height)
-{
-	gog_graph_print_to_gnome_print (
-		SHEET_OBJECT_GRAPH (so)->graph, ctx, width, height);
-}
-#endif
-
 static void
 gnm_sog_draw_cairo (SheetObject const *so, gpointer data,
 			  double width, double height)
 {
 #ifdef GOFFICE_WITH_CAIRO
-	gog_graph_render_to_cairo (
-		SHEET_OBJECT_GRAPH (so)->graph, data, width, height);
+	gog_graph_render_to_cairo_vector
+		(SHEET_OBJECT_GRAPH (so)->graph, data, width, height);
 #endif
 }
 
@@ -435,7 +418,7 @@ static void
 gnm_sog_user_config (SheetObject *so, SheetControl *sc)
 {
 	SheetObjectGraph *sog = SHEET_OBJECT_GRAPH (so);
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	gnm_sog_user_config_t *data;
 	GClosure *closure;
 
@@ -526,12 +509,6 @@ gnm_sog_class_init (GObjectClass *klass)
 	so_class->user_config		= gnm_sog_user_config;
 	so_class->assign_to_sheet	= gnm_sog_set_sheet;
 	so_class->remove_from_sheet	= gnm_sog_remove_from_sheet;
-	so_class->print			= NULL;
-	
-#ifdef WITH_GNOME_PRINT
-	so_class->print			= gnm_sog_print;
-#endif
-
 	so_class->default_size		= gnm_sog_default_size;
 	so_class->draw_cairo		= gnm_sog_draw_cairo;
 	so_class->foreach_dep		= gnm_sog_foreach_dep;
@@ -637,19 +614,23 @@ sheet_object_graph_set_gog (SheetObject *so, GogGraph *graph)
 }
 
 static void
-cb_graph_guru_done (WorkbookControlGUI *wbcg)
+cb_graph_guru_done (WBCGtk *wbcg)
 {
 	wbcg_edit_detach_guru (wbcg);
 	wbcg_edit_finish (wbcg, WBC_EDIT_REJECT, NULL);
 }
 
 void
-sheet_object_graph_guru (WorkbookControlGUI *wbcg, GogGraph *graph,
+sheet_object_graph_guru (WBCGtk *wbcg, GogGraph *graph,
 			 GClosure *closure)
 {
 	GtkWidget *dialog = gog_guru (graph, GOG_DATA_ALLOCATOR (wbcg),
 		       GO_CMD_CONTEXT (wbcg), wbcg_toplevel (wbcg),
 		       closure);
+
+	gnumeric_init_help_button (gog_guru_get_help_button (dialog),
+		"sect-graphics-plots");
+
 	wbcg_edit_attach_guru (wbcg, dialog);
 	g_object_set_data_full (G_OBJECT (dialog),
 		"guru", wbcg, (GDestroyNotify) cb_graph_guru_done);
