@@ -20,7 +20,6 @@
 #include "sheet-private.h"
 #include "dialogs.h"
 #include "sheet-object-impl.h"
-#include "workbook-edit.h"
 #include "expr.h"
 #include "ranges.h"
 #include "commands.h"
@@ -677,6 +676,23 @@ sheet_object_anchor_to_pts (SheetObjectAnchor const *anchor,
 		FALSE, anchor->offset [3]);
 }
 
+static void
+clear_sheet (SheetObject *so, GOUndo **pundo)
+{
+	if (pundo) {
+		GOUndo *u = go_undo_binary_new
+			(g_object_ref (so),
+			 so->sheet,
+			 (GOUndoBinaryFunc)sheet_object_set_sheet,
+			 g_object_unref,
+			 NULL);
+		*pundo = go_undo_combine (*pundo, u);
+	}
+
+	sheet_object_clear_sheet (so);
+}
+
+
 /**
  * sheet_objects_relocate :
  *
@@ -690,7 +706,7 @@ sheet_object_anchor_to_pts (SheetObjectAnchor const *anchor,
  **/
 void
 sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
-			GnmRelocUndo *undo)
+			GOUndo **pundo)
 {
 	GSList   *ptr, *next;
 	GnmRange	 dest;
@@ -711,9 +727,7 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 			SheetObject *so = SHEET_OBJECT (ptr->data);
 			GnmRange const *r  = &so->anchor.cell_bound;
 			if (range_contains (&dest, r->start.col, r->start.row)) {
-				if (NULL != undo)
-					undo->objs = g_slist_prepend (undo->objs, g_object_ref (so));
-				sheet_object_clear_sheet (so);
+				clear_sheet (so, pundo);
 			}
 		}
 		g_slist_free (copy);
@@ -722,21 +736,20 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 	ptr = rinfo->origin_sheet->sheet_objects;
 	for (; ptr != NULL ; ptr = next ) {
 		SheetObject *so = SHEET_OBJECT (ptr->data);
-		GnmRange       *r  = &so->anchor.cell_bound;
+		GnmRange r = so->anchor.cell_bound;
 
 		next = ptr->next;
 		if (update && 0 == (so->flags & SHEET_OBJECT_MOVE_WITH_CELLS))
 			continue;
-		if (range_contains (&rinfo->origin,
-				    r->start.col, r->start.row)) {
+		if (range_contains (&rinfo->origin, r.start.col, r.start.row)) {
 			/* FIXME : just moving the range is insufficent for all anchor types */
 			/* Toss any objects that would be clipped. */
-			if (range_translate (r, rinfo->col_offset, rinfo->row_offset)) {
-				if (NULL != undo)
-					undo->objs = g_slist_prepend (undo->objs, g_object_ref (so));
-				sheet_object_clear_sheet (so);
+			if (range_translate (&r, rinfo->col_offset, rinfo->row_offset)) {
+				clear_sheet (so, pundo);
 				continue;
 			}
+			so->anchor.cell_bound = r;
+
 			if (change_sheets) {
 				g_object_ref (so);
 				sheet_object_clear_sheet (so);
@@ -745,10 +758,8 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 			} else if (update)
 				sheet_object_update_bounds (so, NULL);
 		} else if (!change_sheets &&
-			   range_contains (&dest, r->start.col, r->start.row)) {
-			if (NULL != undo)
-				undo->objs = g_slist_prepend (undo->objs, g_object_ref (so));
-			sheet_object_clear_sheet (so);
+			   range_contains (&dest, r.start.col, r.start.row)) {
+			clear_sheet (so, pundo);
 			continue;
 		}
 	}
@@ -798,7 +809,8 @@ sheet_objects_get (Sheet const *sheet, GnmRange const *r, GType t)
  * removes the objects in the region.
  **/
 void
-sheet_objects_clear (Sheet const *sheet, GnmRange const *r, GType t)
+sheet_objects_clear (Sheet const *sheet, GnmRange const *r, GType t,
+		     GOUndo **pundo)
 {
 	GSList *ptr, *next;
 
@@ -809,10 +821,8 @@ sheet_objects_clear (Sheet const *sheet, GnmRange const *r, GType t)
 		next = ptr->next;
 		if (t == G_TYPE_NONE || t == G_OBJECT_TYPE (obj)) {
 			SheetObject *so = SHEET_OBJECT (obj);
-			if (r == NULL || range_contained (&so->anchor.cell_bound, r)) {
-				/* lost_objs = g_slist_prepend (lost_objs, g_object_ref (so)); */
-				sheet_object_clear_sheet (so);
-			}
+			if (r == NULL || range_contained (&so->anchor.cell_bound, r))
+				clear_sheet (so, pundo);
 		}
 	}
 }
@@ -973,42 +983,70 @@ sheet_object_anchor_init (SheetObjectAnchor *anchor,
 
 /*****************************************************************************/
 
+/**
+ * sheet_object_get_stacking :
+ * @so : #SheetObject
+ *
+ * Returns @so's position in the stack of sheet objects.
+ **/
 gint
 sheet_object_get_stacking (SheetObject *so)
 {
-	GList *l = so->realized_list;
+	GSList *ptr;
+	int	pos = 0;
 
-	if (l != NULL) {
-		FooCanvasItem *item = FOO_CANVAS_ITEM (l->data);
-		FooCanvasGroup *parent = FOO_CANVAS_GROUP (item->parent);
-		GList *link = g_list_find (parent->item_list, item);
-		return g_list_position (parent->item_list, link);
-	}
-	return -1;
+	g_return_val_if_fail (so != NULL, 0);
+	g_return_val_if_fail (so->sheet != NULL, 0);
+
+	for (ptr = so->sheet->sheet_objects ;  ptr ; ptr = ptr->next, pos++)
+		if (ptr->data == so)
+			return pos;
+
+	g_warning ("Object not found??");
+	return 0;
 }
 
-/*****************************************************************************/
-
 gint
-sheet_object_adjust_stacking (SheetObject *so, gint positions)
+sheet_object_adjust_stacking (SheetObject *so, gint offset)
 {
-	GList *l;
-	gint before = -1;
-	gint after = -1;
+	GList	 *l;
+	GSList	**ptr, *node = NULL;
+	int	  i, target, cur = 0;
 
+	g_return_val_if_fail (so != NULL, 0);
+	g_return_val_if_fail (so->sheet != NULL, 0);
+
+	for (ptr = &so->sheet->sheet_objects ; *ptr ; ptr = &(*ptr)->next, cur++)
+		if ((*ptr)->data == so) {
+			node = *ptr;
+			*ptr = (*ptr)->next;
+			break;
+		}
+
+	g_return_val_if_fail (node != NULL, 0);
+
+	/* Start at the begining when moving things towards the front */
+	if (offset > 0) {
+		ptr = &so->sheet->sheet_objects;
+		i = 0;
+	} else
+		i = cur;
+
+	for (target = cur - offset; *ptr && i < target ; ptr = &(*ptr)->next)
+		i++;
+
+	node->next = *ptr;
+	*ptr = node;
+
+	/* TODO : Move this to the container */
 	for (l = so->realized_list; l; l = l->next) {
 		FooCanvasItem *item = FOO_CANVAS_ITEM (l->data);
-		FooCanvasGroup *parent = FOO_CANVAS_GROUP (item->parent);
-		GList *link = g_list_find (parent->item_list, item);
-		before = g_list_position (parent->item_list, link);
-		if (positions > 0)
-			foo_canvas_item_raise (item, positions);
+		if (offset > 0)
+			foo_canvas_item_raise (item, offset);
 		else
-			foo_canvas_item_lower (item, - positions);
-		link = g_list_find (parent->item_list, item);
-		after = g_list_position (parent->item_list, link);
+			foo_canvas_item_lower (item, - offset);
 	}
-	return ((before == -1 || after == -1) ? positions : (after - before));
+	return cur - i;
 }
 
 /*****************************************************************************/
