@@ -6,6 +6,7 @@
 #include "colrow.h"
 #include "position.h"
 #include <pango/pango.h>
+#include <goffice/utils/go-undo.h>
 
 typedef struct _SheetPrivate SheetPrivate;
 typedef enum {
@@ -28,14 +29,8 @@ struct _Sheet {
 	int         index_in_wb;
 	Workbook    *workbook;
 	gboolean    being_invalidated;
-	struct {
-		/* An alternating list of ref'd names and texpressions.  */
-		GSList *name_texprs;
-		/* An alternating list of deps and ref'd texpressions.  */
-		GSList *dep_texprs;
-		/* A list of deps to relink.  */
-		GSList *relink;
-	} revive;
+
+	GOUndoGroup *revive;
 
 	GPtrArray   *sheet_views;
 
@@ -58,13 +53,31 @@ struct _Sheet {
 	GnmCellPos   max_object_extent;
 
 	/* Sheet level preferences */
-	gboolean    r1c1_addresses;
+	GnmConventions const *convs;
 	gboolean    display_formulas;
 	gboolean    hide_zero;
 	gboolean    hide_grid;
 	gboolean    hide_col_header;
 	gboolean    hide_row_header;
 	gboolean    is_protected;
+	struct {
+		gboolean edit_objects;		/* TODO */
+		gboolean edit_scenarios;	/* TODO */
+		gboolean cell_formatting;	/* TODO */
+		gboolean column_formatting;	/* TODO */
+		gboolean row_formatting;	/* TODO */
+		gboolean insert_columns;	/* TODO */
+		gboolean insert_rows;		/* TODO */
+		gboolean insert_hyperlinks;	/* TODO */
+		gboolean delete_columns;	/* TODO */
+		gboolean delete_rows;		/* TODO */
+		gboolean select_locked_cells;	/* Partial : TODO range selection */
+		gboolean sort_ranges;		/* TODO */
+		gboolean edit_auto_filters;	/* TODO */
+		gboolean edit_pivottable;	/* TODO */
+		gboolean select_unlocked_cells;	/* Partial : TODO range selection */
+	} protected_allow;
+
 	GnmSheetVisibility visibility;
 
 	gboolean    display_outlines;
@@ -90,7 +103,6 @@ struct _Sheet {
 	GnmColor	 *tab_color;
 	GnmColor	 *tab_text_color;
 	GnmSheetType	  sheet_type;
-	GnmExprConventions const *convs;
 
 	/* This needs to move elsewhere and get shared.  */
 	PangoContext *context;
@@ -252,7 +264,7 @@ void     sheet_redraw_region    (Sheet const *sheet,
 
 void	 sheet_flag_status_update_cell	(GnmCell const *c);
 void	 sheet_flag_status_update_range	(Sheet const *s, GnmRange const *r);
-void     sheet_flag_format_update_range	(Sheet const *s, GnmRange const *r);
+void     sheet_flag_style_update_range	(Sheet const *s, GnmRange const *r);
 void	 sheet_flag_recompute_spans	(Sheet const *s);
 void	 sheet_update_only_grid		(Sheet const *s);
 void     sheet_update                   (Sheet const *s);
@@ -262,7 +274,8 @@ void     sheet_mark_dirty	(Sheet *sheet);
 GnmRange    sheet_get_extent	(Sheet const *sheet,
 				 gboolean spans_and_merges_extend);
 GnmRange    sheet_get_printarea	(Sheet const *sheet,
-				 gboolean include_styles);
+				 gboolean include_styles,
+				 gboolean ignore_printarea);
 GnmRange    sheet_get_nominal_printarea	(Sheet const *sheet);
 
 /*
@@ -283,27 +296,20 @@ void	     sheet_range_calc_spans (Sheet *sheet, GnmRange const *r, GnmSpanCalcFl
 void	     sheet_cell_calc_span   (GnmCell *cell, GnmSpanCalcFlags flags);
 
 void	     sheet_set_outline_direction (Sheet *sheet, gboolean is_cols);
+gboolean     sheet_selection_is_allowed (Sheet const *sheet, GnmCellPos const *pos);
 
-/* Implementation for commands, no undo */
-struct _GnmRelocUndo {
-	GSList *exprs;
-	GSList *objs;
-};
+GnmConventions const *sheet_get_conventions (Sheet const *sheet);
 
-gboolean  sheet_insert_cols (Sheet *sheet,
-			     int col, int count, ColRowStateList *states,
-			     GnmRelocUndo *reloc_storage, GOCmdContext *cc);
-gboolean  sheet_delete_cols (Sheet *sheet,
-			     int col, int count, ColRowStateList *states,
-			     GnmRelocUndo *reloc_storage, GOCmdContext *cc);
-gboolean  sheet_insert_rows (Sheet *sheet,
-			     int row, int count, ColRowStateList *states,
-			     GnmRelocUndo *reloc_storage, GOCmdContext *cc);
-gboolean  sheet_delete_rows (Sheet *sheet,
-			     int row, int count, ColRowStateList *states,
-			     GnmRelocUndo *reloc_storage, GOCmdContext *cc);
+gboolean  sheet_insert_cols (Sheet *sheet, int col, int count,
+			     GOUndo **pundo, GOCmdContext *cc);
+gboolean  sheet_delete_cols (Sheet *sheet, int col, int count,
+			     GOUndo **pundo, GOCmdContext *cc);
+gboolean  sheet_insert_rows (Sheet *sheet, int row, int count,
+			     GOUndo **pundo, GOCmdContext *cc);
+gboolean  sheet_delete_rows (Sheet *sheet, int row, int count,
+			     GOUndo **pundo, GOCmdContext *cc);
 void      sheet_move_range   (GnmExprRelocateInfo const *rinfo,
-			      GnmRelocUndo *reloc_storage, GOCmdContext *cc);
+			      GOUndo **pundo, GOCmdContext *cc);
 
 
 typedef enum {
