@@ -153,6 +153,7 @@ ssindex (char const *file, IOContext *ioc)
 	char	   *str = go_shell_arg_to_uri (file);
 	IndexerState state;
 	GsfOutput  *gsf_stdout;
+	Workbook   *wb;
 
 	state.wb_view = wb_view_new_from_uri (str, NULL,
 		ioc, ssindex_import_encoding);
@@ -164,9 +165,9 @@ ssindex (char const *file, IOContext *ioc)
 	gsf_stdout = gsf_output_stdio_new_FILE ("<stdout>", stdout, TRUE);
 	state.output = gsf_xml_out_new (gsf_stdout);
 	gsf_xml_out_start_element (state.output, "gnumeric");
-	state.wb = wb_view_get_workbook (state.wb_view);
-	for (i = 0 ; i < workbook_sheet_count (state.wb); i++) {
-		state.sheet = workbook_sheet_by_index (state.wb, i);
+	state.wb = wb = wb_view_get_workbook (state.wb_view);
+	for (i = 0 ; i < workbook_sheet_count (wb); i++) {
+		state.sheet = workbook_sheet_by_index (wb, i);
 		gsf_xml_out_simple_element (state.output,
 			"data", state.sheet->name_unquoted);
 
@@ -200,13 +201,13 @@ ssindex (char const *file, IOContext *ioc)
 	gsf_output_close (gsf_stdout);
 	g_object_unref (gsf_stdout);
 
-	g_object_unref ((gpointer)state.wb);
+	g_object_unref (wb);
 
 	return res;
 }
 
 int
-main (int argc, char **argv)
+main (int argc, char const **argv)
 {
 	ErrorInfo	*plugin_errs;
 	int		 res = 0;
@@ -214,13 +215,12 @@ main (int argc, char **argv)
 	GOptionContext *ocontext;
 	GError *error = NULL;	
 
-	g_thread_init (NULL);
-
-	gnm_pre_parse_init (argv[0]);
+	/* No code before here, we need to init threads */
+	argv = gnm_pre_parse_init (argc, argv);
 
 	ocontext = g_option_context_new (_("INFILE..."));
 	g_option_context_add_main_entries (ocontext, ssindex_options, GETTEXT_PACKAGE);
-	g_option_context_parse (ocontext, &argc, &argv, &error);
+	g_option_context_parse (ocontext, &argc, (gchar ***)&argv, &error);
 	g_option_context_free (ocontext);
 
 	if (error) {
@@ -241,7 +241,7 @@ main (int argc, char **argv)
 		return 1;
 	}
 
-	gnm_common_init (FALSE);
+	gnm_init (FALSE);
 
 	cc = cmd_context_stderr_new ();
 	gnm_plugins_init (GO_CMD_CONTEXT (cc));
@@ -271,6 +271,7 @@ main (int argc, char **argv)
 
 	g_object_unref (cc);
 	gnm_shutdown ();
+	gnm_pre_parse_shutdown ();
 
 	return res;
 }
