@@ -1,4 +1,4 @@
-/* vim: set sw=8: */
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * border.c: Managing drawing and printing cell borders
@@ -340,53 +340,6 @@ style_border_get_gc (GnmBorder const *border, GdkDrawable *drawable)
 	return border->gc;
 }
 
-#ifdef WITH_GNOME_PRINT
-static void
-style_border_set_pc_dash (GnmStyleBorderType const i,
-			  GnomePrintContext *context)
-{
-	GdkLineStyle style = GDK_LINE_SOLID;
-	int w;
-
-	g_return_if_fail (context != NULL);
-	g_return_if_fail (i >= GNM_STYLE_BORDER_NONE);
-	g_return_if_fail (i < GNM_STYLE_BORDER_MAX);
-
-	if (i == GNM_STYLE_BORDER_NONE)
-		return;
-
-	if (style_border_data[i].pattern != NULL)
-		style = GDK_LINE_ON_OFF_DASH;
-
-	w = style_border_data[i].width;
-	if (w == 0)
-		w = 1;
-	gnome_print_setlinewidth (context, w);
-
-	if (style_border_data[i].pattern != NULL) {
-		struct LineDotPattern const * const pat =
-			style_border_data[i].pattern;
-		gnome_print_setdash (context, pat->elements,
-				     pat->pattern_d, style_border_data[i].offset);
-	}
-}
-
-static inline gboolean
-style_border_set_pc (GnmBorder const * const border,
-		     GnomePrintContext *context)
-{
-	if (border == NULL)
-		return FALSE;
-
-	gnome_print_gsave (context);
-	style_border_set_pc_dash (border->line_type, context);
-	gnome_print_setrgbcolor (context,
-				 border->color->gdk_color.red   / (double) 0xffff,
-				 border->color->gdk_color.green / (double) 0xffff,
-				 border->color->gdk_color.blue  / (double) 0xffff);
-	return TRUE;
-}
-#endif /* WITH_GNOME_PRINT */
 
 GnmBorder *
 gnm_style_border_ref (GnmBorder *border)
@@ -725,45 +678,89 @@ gnm_style_border_draw_diag (GnmStyle const *style,
 	}
 }
 
-#ifdef WITH_GNOME_PRINT
-static inline void
-print_hline (GnomePrintContext *context,
-	     float x1, float x2, float y, int width)
+static void
+style_border_set_gtk_dash (GnmStyleBorderType const i,
+			   cairo_t *context)
 {
-	if (width == 0 || width % 2)
-		y -= .5;
+	GdkLineStyle style = GDK_LINE_SOLID;
+	int w;
 
-	/* exclude far pixel to match gdk */
-	gnome_print_moveto (context, x1, y);
-	gnome_print_lineto (context, x2, y);
-	gnome_print_stroke (context);
+	g_return_if_fail (context != NULL);
+	g_return_if_fail (i >= GNM_STYLE_BORDER_NONE);
+	g_return_if_fail (i < GNM_STYLE_BORDER_MAX);
+
+	if (style_border_data[i].pattern != NULL)
+		style = GDK_LINE_ON_OFF_DASH;
+
+	w = style_border_data[i].width;
+	if (w == 0)
+		w = 1;
+	cairo_set_line_width (context,((double) w));
+
+ 	if (style_border_data[i].pattern != NULL) { 
+ 		struct LineDotPattern const * const pat = 
+ 			style_border_data[i].pattern; 
+ 		cairo_set_dash (context, pat->pattern_d, pat->elements, 
+ 				style_border_data[i].offset); 
+ 	} else 
+		cairo_set_dash (context, NULL, 0, 0); 
+}
+
+static inline gboolean
+style_border_set_gtk (GnmBorder const * const border,
+		      cairo_t *context)
+{
+	if (border == NULL)
+		return FALSE;
+
+	style_border_set_gtk_dash (border->line_type, context);
+	cairo_set_source_rgb (context,
+			      border->color->gdk_color.red   / (double) 0xffff,
+			      border->color->gdk_color.green / (double) 0xffff,
+			      border->color->gdk_color.blue  / (double) 0xffff);
+	return TRUE;
 }
 
 static inline void
-print_vline (GnomePrintContext *context,
-	     float x, float y1, float y2, int width, int dir)
+print_hline_gtk (cairo_t *context,
+		 float x1, float x2, float y, int width)
+{
+	if (width == 0 || width % 2)
+		y += .5;
+
+	/* exclude far pixel to match gdk */
+	cairo_move_to (context, x1, y);
+	cairo_line_to (context, x2, y);
+	cairo_stroke (context);
+}
+
+static inline void
+print_vline_gtk (cairo_t *context,
+		 float x, float y1, float y2, int width, int dir)
 {
 	if (width == 0 || width % 2)
 		x += .5*dir;
 
 	/* exclude far pixel to match gdk */
-	gnome_print_moveto (context, x, y1);
-	gnome_print_lineto (context, x, y2);
-	gnome_print_stroke (context);
+	cairo_move_to (context, x, y1);
+	cairo_line_to (context, x, y2);
+	cairo_stroke (context);
 }
 
 void
-gnm_style_borders_row_print (GnmBorder const * const * prev_vert,
-			     GnmStyleRow const *sr,
-			     GnomePrintContext *context,
-			     float x, float y1, float y2,
-			     Sheet const *sheet,
-			     gboolean draw_vertical, int dir)
+gnm_style_borders_row_print_gtk (GnmBorder const * const * prev_vert,
+				 GnmStyleRow const *sr,
+				 cairo_t *context,
+				 float x, float y1, float y2,
+				 Sheet const *sheet,
+				 gboolean draw_vertical, int dir)
 {
 	int o[2][2], col;
 	float next_x = x;
 	GnmBorder const *border;
 
+	cairo_save (context);
+
 	for (col = sr->start_col; col <= sr->end_col ; col++, x = next_x) {
 		/* TODO : make this sheet agnostic.  Pass in an array of
 		 * widths and a flag for whether or not to draw grids.
@@ -774,91 +771,95 @@ gnm_style_borders_row_print (GnmBorder const * const * prev_vert,
 		next_x = x + dir * cri->size_pts;
 
 		border = sr->top [col];
-		if (style_border_set_pc (border, context)) {
+
+		if (style_border_set_gtk (border, context)) {
 			float y = y1;
 			if (style_border_hmargins (prev_vert, sr, col, o, dir)) {
-				print_hline (context, x + o[1][0],
-					     next_x + o[1][1] + dir, y1+1., border->width);
-				--y;
+				print_hline_gtk (context, x + o[1][0],
+						 next_x + o[1][1] + dir, y1-1.,
+						 border->width);
+				++y;
 			}
 
-			print_hline (context, x + o[0][0],
-				     next_x + o[0][1] + dir, y, border->width);
-			gnome_print_grestore (context);
+			print_hline_gtk (context, x + o[0][0],
+					 next_x + o[0][1] + dir, y, border->width);
 		}
 
 		if (!draw_vertical)
 			continue;
+
+		
 		border = sr->vertical [col];
-		if (style_border_set_pc (border, context)) {
+		if (style_border_set_gtk (border, context)) {
 			float x1 = x;
 			if (style_border_vmargins (prev_vert, sr, col, o)) {
-				print_vline (context, x-dir, y1 - o[1][0],
-					     y2 - o[1][1] - 1., border->width, dir);
+				print_vline_gtk (context, x-dir, y1 + o[1][0],
+						 y2 + o[1][1] + 1., border->width, dir);
 				x1 += dir;
 			}
-			print_vline (context, x1, y1 - o[0][0],
-				     y2 - o[0][1] - 1., border->width, dir);
-			gnome_print_grestore (context);
+			print_vline_gtk (context, x1, y1 + o[0][0],
+					 y2 + o[0][1] + 1., border->width, dir);
 		}
 	}
 	if (draw_vertical) {
 		border = sr->vertical [col];
-		if (style_border_set_pc (border, context)) {
+		if (style_border_set_gtk (border, context)) {
 			float x1 = x;
 			if (style_border_vmargins (prev_vert, sr, col, o)) {
-				print_vline (context, x-dir, y1 - o[1][0] - 1.,
-					    y2 - o[1][1], border->width, dir);
+				print_vline_gtk (context, x-dir, y1 + o[1][0] + 1.,
+						 y2 + o[1][1], border->width, dir);
 				x1 += dir;
 			}
 			/* See note in gnm_style_border_set_gc_dash about +1 */
-			print_vline (context, x1, y1 - o[0][0],
-				     y2 - o[0][1] - 1, border->width, dir);
-			gnome_print_grestore (context);
+			print_vline_gtk (context, x1, y1 + o[0][0],
+					 y2 + o[0][1] + 1, border->width, dir);
 		}
 	}
+
+	cairo_restore (context);
 }
 
 void
-gnm_style_border_print_diag (GnmStyle const *style,
-			     GnomePrintContext *context,
+gnm_style_border_print_diag_gtk (GnmStyle const *style,
+			     cairo_t *context,
 			     float x1, float y1, float x2, float y2)
 {
 	GnmBorder const *diag;
 
+
+	cairo_save (context);
+
 	diag = gnm_style_get_border (style, MSTYLE_BORDER_REV_DIAGONAL);
 	if (diag != NULL && diag->line_type != GNM_STYLE_BORDER_NONE) {
-		style_border_set_pc (diag, context);
+		style_border_set_gtk (diag, context);
 		if (diag->line_type == GNM_STYLE_BORDER_DOUBLE) {
-			gnome_print_moveto (context, x1+1.5,  y1-3.);
-			gnome_print_lineto (context, x2-2.,   y2+ .5);
-			gnome_print_stroke (context);
-			gnome_print_moveto (context, x1+ 3.,  y1-1.5);
-			gnome_print_lineto (context, x2-  .5, y2+2.);
+			cairo_move_to (context, x1+1.5,  y1+3.);
+			cairo_line_to (context, x2-2.,   y2- .5);
+			cairo_stroke (context);
+			cairo_move_to (context, x1+ 3.,  y1+1.5);
+			cairo_line_to (context, x2-  .5, y2-2.);
 		} else {
-			gnome_print_moveto (context, x1+.5, y1-.5);
-			gnome_print_lineto (context, x2+.5, y2-.5);
+			cairo_move_to (context, x1+.5, y1+.5);
+			cairo_line_to (context, x2+.5, y2+.5);
 		}
-		gnome_print_stroke (context);
-		gnome_print_grestore (context);
+		cairo_stroke (context);
 	}
 
 	diag = gnm_style_get_border (style, MSTYLE_BORDER_DIAGONAL);
 	if (diag != NULL && diag->line_type != GNM_STYLE_BORDER_NONE) {
-		style_border_set_pc (diag, context);
+		style_border_set_gtk (diag, context);
 		if (diag->line_type == GNM_STYLE_BORDER_DOUBLE) {
-			gnome_print_moveto (context, x1+1.5, y2+2.);
-			gnome_print_lineto (context, x2-2.,  y1-1.5);
-			gnome_print_stroke (context);
-			gnome_print_moveto (context, x1+3.,  y2+ .5);
-			gnome_print_lineto (context, x2- .5, y1-3.);
+			cairo_move_to (context, x1+1.5, y2-2.);
+			cairo_line_to (context, x2-2.,  y1+1.5);
+			cairo_stroke (context);
+			cairo_move_to (context, x1+3.,  y2- .5);
+			cairo_line_to (context, x2- .5, y1+3.);
 		} else {
-			gnome_print_moveto (context, x1+.5, y2-.5);
-			gnome_print_lineto (context, x2+.5, y1-.5);
+			cairo_move_to (context, x1+.5, y2+.5);
+			cairo_line_to (context, x2+.5, y1+.5);
 		}
-		gnome_print_stroke (context);
-		gnome_print_grestore (context);
+		cairo_stroke (context);
 	}
+	
+	cairo_restore (context);
 }
-
-#endif /* WITH_GNOME_PRINT */
