@@ -17,10 +17,9 @@
  */
 
 #include <gnumeric-config.h>
-#include <gdk/gdkx.h>
 #include "gnumeric-cell-renderer-expr-entry.h"
 #include "gnumeric-expr-entry.h"
-#include "workbook-edit.h"
+#include "wbc-gtk.h"
 
 #define GNUMERIC_CELL_RENDERER_EXPR_ENTRY_PATH "gnumeric-cell-renderer-expr-entry-path"
 
@@ -81,7 +80,7 @@ gnumeric_cell_renderer_expr_entry_class_init (GnumericCellRendererExprEntryClass
 
 
 GtkCellRenderer *
-gnumeric_cell_renderer_expr_entry_new (WorkbookControlGUI *wbcg)
+gnumeric_cell_renderer_expr_entry_new (WBCGtk *wbcg)
 {
 	GnumericCellRendererExprEntry *this = 
 		GNUMERIC_CELL_RENDERER_EXPR_ENTRY(g_object_new 
