@@ -54,6 +54,7 @@
 #include <goffice/app/io-context.h>
 #include <goffice/utils/go-file.h>
 #include <goffice/utils/go-glib-extras.h>
+#include <goffice/utils/go-locale.h>
 #include <gsf/gsf.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-stdio.h>
@@ -233,6 +234,7 @@ wb_view_style_feedback (WorkbookView *wbv)
 	GnmValidation const *val;
 	GOFormat *fmt_style, *fmt_cell;
 	GnmCell *cell;
+	gboolean update_controls = TRUE;
 
 	g_return_if_fail (IS_WORKBOOK_VIEW (wbv));
 
@@ -252,7 +254,7 @@ wb_view_style_feedback (WorkbookView *wbv)
 
 	if (go_format_eq (fmt_cell, fmt_style)) {
 		if (style == wbv->current_style)
-			return;
+			update_controls = FALSE;
 		gnm_style_ref (style);
 	} else {
 		GnmStyle *tmp = gnm_style_dup (style);
@@ -274,20 +276,24 @@ wb_view_style_feedback (WorkbookView *wbv)
 	    NULL != (val = gnm_style_get_validation (style)) &&
 	    val->type == VALIDATION_TYPE_IN_LIST &&
 	    val->use_dropdown) {
-		static float const a_offsets [4] = { 0., 0., 1., 1. };
+		float const a_offsets [4] = { 0., 0., 1., 1. };
 		SheetObjectAnchor  anchor;
-		GnmRange r;
-		
-		range_init_cellpos_size (&r, &sv->edit_pos, 1, 1);
+		GnmRange corner;
+		GnmRange const *r;
+
+		if (NULL == (r = gnm_sheet_merge_contains_pos (sv->sheet, &sv->edit_pos)))
+			r = range_init_cellpos_size (&corner, &sv->edit_pos, 1, 1);
 		wbv->validation_combo = gnm_validation_combo_new (val, sv);
-		sheet_object_anchor_init (&anchor, &r, a_offsets, NULL,
+		sheet_object_anchor_init (&anchor, r, a_offsets,
 			GOD_ANCHOR_DIR_DOWN_RIGHT);
 		sheet_object_set_anchor (wbv->validation_combo, &anchor);
 		sheet_object_set_sheet (wbv->validation_combo, sv_sheet (sv));
 	}
 
-	WORKBOOK_VIEW_FOREACH_CONTROL(wbv, control,
-		wb_control_style_feedback (control, NULL););
+	if (update_controls) {
+		WORKBOOK_VIEW_FOREACH_CONTROL(wbv, control,
+			wb_control_style_feedback (control, NULL););
+	}
 }
 
 void
@@ -329,8 +335,11 @@ wb_view_selection_desc (WorkbookView *wbv, gboolean use_pos,
 		    (NULL != (m = gnm_sheet_merge_is_corner (sv->sheet, &r->start)) &&
 		     range_equal (r, m))) {
 			sel_descr = sheet_names_check (sv->sheet, r);
-			if (sel_descr == NULL)
-				sel_descr = cellpos_as_string (&sv->edit_pos);
+			if (sel_descr == NULL) {
+				GnmParsePos pp;
+				parse_pos_init_editpos (&pp, sv);
+				sel_descr = parsepos_as_string (&pp);
+			}
 		} else {
 			int rows = r->end.row - r->start.row + 1;
 			int cols = r->end.col - r->start.col + 1;
@@ -402,9 +411,9 @@ wb_view_edit_line_set (WorkbookView *wbv, WorkbookControl *optional_wbc)
 				case GNM_EXPR_OP_ARRAY_CORNER :
 					tmp = g_strdup_printf ("{%s}(%d%c%d)[%d][%d]", text,
 						expr->array_corner.cols,
-						go_format_get_arg_sep (),
+						go_locale_get_arg_sep (),
 						expr->array_corner.rows,
-						y, x);
+						x, y);
 					g_free (text);
 					text = tmp;
 					break;
